#line 1 "src/compiler/glsl/glsl_lexer.cpp"

#line 3 "src/compiler/glsl/glsl_lexer.cpp"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define _mesa_glsl_lexer__create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer _mesa_glsl_lexer__create_buffer
#endif

#ifdef yy_delete_buffer
#define _mesa_glsl_lexer__delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer _mesa_glsl_lexer__delete_buffer
#endif

#ifdef yy_scan_buffer
#define _mesa_glsl_lexer__scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer _mesa_glsl_lexer__scan_buffer
#endif

#ifdef yy_scan_string
#define _mesa_glsl_lexer__scan_string_ALREADY_DEFINED
#else
#define yy_scan_string _mesa_glsl_lexer__scan_string
#endif

#ifdef yy_scan_bytes
#define _mesa_glsl_lexer__scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes _mesa_glsl_lexer__scan_bytes
#endif

#ifdef yy_init_buffer
#define _mesa_glsl_lexer__init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer _mesa_glsl_lexer__init_buffer
#endif

#ifdef yy_flush_buffer
#define _mesa_glsl_lexer__flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer _mesa_glsl_lexer__flush_buffer
#endif

#ifdef yy_load_buffer_state
#define _mesa_glsl_lexer__load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state _mesa_glsl_lexer__load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define _mesa_glsl_lexer__switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer _mesa_glsl_lexer__switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define _mesa_glsl_lexer_push_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state _mesa_glsl_lexer_push_buffer_state
#endif

#ifdef yypop_buffer_state
#define _mesa_glsl_lexer_pop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state _mesa_glsl_lexer_pop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define _mesa_glsl_lexer_ensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack _mesa_glsl_lexer_ensure_buffer_stack
#endif

#ifdef yylex
#define _mesa_glsl_lexer_lex_ALREADY_DEFINED
#else
#define yylex _mesa_glsl_lexer_lex
#endif

#ifdef yyrestart
#define _mesa_glsl_lexer_restart_ALREADY_DEFINED
#else
#define yyrestart _mesa_glsl_lexer_restart
#endif

#ifdef yylex_init
#define _mesa_glsl_lexer_lex_init_ALREADY_DEFINED
#else
#define yylex_init _mesa_glsl_lexer_lex_init
#endif

#ifdef yylex_init_extra
#define _mesa_glsl_lexer_lex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra _mesa_glsl_lexer_lex_init_extra
#endif

#ifdef yylex_destroy
#define _mesa_glsl_lexer_lex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy _mesa_glsl_lexer_lex_destroy
#endif

#ifdef yyget_debug
#define _mesa_glsl_lexer_get_debug_ALREADY_DEFINED
#else
#define yyget_debug _mesa_glsl_lexer_get_debug
#endif

#ifdef yyset_debug
#define _mesa_glsl_lexer_set_debug_ALREADY_DEFINED
#else
#define yyset_debug _mesa_glsl_lexer_set_debug
#endif

#ifdef yyget_extra
#define _mesa_glsl_lexer_get_extra_ALREADY_DEFINED
#else
#define yyget_extra _mesa_glsl_lexer_get_extra
#endif

#ifdef yyset_extra
#define _mesa_glsl_lexer_set_extra_ALREADY_DEFINED
#else
#define yyset_extra _mesa_glsl_lexer_set_extra
#endif

#ifdef yyget_in
#define _mesa_glsl_lexer_get_in_ALREADY_DEFINED
#else
#define yyget_in _mesa_glsl_lexer_get_in
#endif

#ifdef yyset_in
#define _mesa_glsl_lexer_set_in_ALREADY_DEFINED
#else
#define yyset_in _mesa_glsl_lexer_set_in
#endif

#ifdef yyget_out
#define _mesa_glsl_lexer_get_out_ALREADY_DEFINED
#else
#define yyget_out _mesa_glsl_lexer_get_out
#endif

#ifdef yyset_out
#define _mesa_glsl_lexer_set_out_ALREADY_DEFINED
#else
#define yyset_out _mesa_glsl_lexer_set_out
#endif

#ifdef yyget_leng
#define _mesa_glsl_lexer_get_leng_ALREADY_DEFINED
#else
#define yyget_leng _mesa_glsl_lexer_get_leng
#endif

#ifdef yyget_text
#define _mesa_glsl_lexer_get_text_ALREADY_DEFINED
#else
#define yyget_text _mesa_glsl_lexer_get_text
#endif

#ifdef yyget_lineno
#define _mesa_glsl_lexer_get_lineno_ALREADY_DEFINED
#else
#define yyget_lineno _mesa_glsl_lexer_get_lineno
#endif

#ifdef yyset_lineno
#define _mesa_glsl_lexer_set_lineno_ALREADY_DEFINED
#else
#define yyset_lineno _mesa_glsl_lexer_set_lineno
#endif

#ifdef yyget_column
#define _mesa_glsl_lexer_get_column_ALREADY_DEFINED
#else
#define yyget_column _mesa_glsl_lexer_get_column
#endif

#ifdef yyset_column
#define _mesa_glsl_lexer_set_column_ALREADY_DEFINED
#else
#define yyset_column _mesa_glsl_lexer_set_column
#endif

#ifdef yywrap
#define _mesa_glsl_lexer_wrap_ALREADY_DEFINED
#else
#define yywrap _mesa_glsl_lexer_wrap
#endif

#ifdef yyget_lval
#define _mesa_glsl_lexer_get_lval_ALREADY_DEFINED
#else
#define yyget_lval _mesa_glsl_lexer_get_lval
#endif

#ifdef yyset_lval
#define _mesa_glsl_lexer_set_lval_ALREADY_DEFINED
#else
#define yyset_lval _mesa_glsl_lexer_set_lval
#endif

#ifdef yyget_lloc
#define _mesa_glsl_lexer_get_lloc_ALREADY_DEFINED
#else
#define yyget_lloc _mesa_glsl_lexer_get_lloc
#endif

#ifdef yyset_lloc
#define _mesa_glsl_lexer_set_lloc_ALREADY_DEFINED
#else
#define yyset_lloc _mesa_glsl_lexer_set_lloc
#endif

#ifdef yyalloc
#define _mesa_glsl_lexer_alloc_ALREADY_DEFINED
#else
#define yyalloc _mesa_glsl_lexer_alloc
#endif

#ifdef yyrealloc
#define _mesa_glsl_lexer_realloc_ALREADY_DEFINED
#else
#define yyrealloc _mesa_glsl_lexer_realloc
#endif

#ifdef yyfree
#define _mesa_glsl_lexer_free_ALREADY_DEFINED
#else
#define yyfree _mesa_glsl_lexer_free
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin , yyscanner )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void yyrestart ( FILE *input_file , yyscan_t yyscanner );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size , yyscan_t yyscanner );
void yy_delete_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yy_flush_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
void yypop_buffer_state ( yyscan_t yyscanner );

static void yyensure_buffer_stack ( yyscan_t yyscanner );
static void yy_load_buffer_state ( yyscan_t yyscanner );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file , yyscan_t yyscanner );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER , yyscanner)

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len , yyscan_t yyscanner );

void *yyalloc ( yy_size_t , yyscan_t yyscanner );
void *yyrealloc ( void *, yy_size_t , yyscan_t yyscanner );
void yyfree ( void * , yyscan_t yyscanner );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define _mesa_glsl_lexer_wrap(yyscanner) (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state ( yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  , yyscan_t yyscanner);
static int yy_get_next_buffer ( yyscan_t yyscanner );
static void yynoreturn yy_fatal_error ( const char* msg , yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;
#define YY_NUM_RULES 302
#define YY_END_OF_BUFFER 303
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[1187] =
    {   0,
        0,    0,   20,   20,    0,    0,  303,  301,    1,   27,
      301,  301,  301,  301,  301,  301,  300,  301,  187,  185,
      301,  301,  301,  299,  301,  299,  299,  299,  299,  299,
      299,  299,  299,  299,  299,  299,  299,  299,  299,  299,
      299,  299,  299,  299,  299,  301,    1,  301,   26,   20,
       25,   26,   24,   23,   21,   22,   18,   17,    1,  169,
      178,  170,  181,  175,  164,  177,  165,  184,  193,  176,
      194,  187,    0,    0,  187,  187,    0,  187,  185,  185,
      185,  185,  173,  166,  168,  167,  174,  299,  182,  172,
      299,  299,  299,  299,  299,  299,  299,  299,  299,  299,

      299,  299,  299,  299,   36,  299,  299,  299,  299,  299,
      299,  299,  299,  299,  299,  299,  299,  299,  299,  299,
       40,  299,  299,   68,  299,  299,  299,  299,  299,  299,
      299,  299,  299,  299,  299,  299,  299,  299,  299,  299,
      299,  299,  299,  299,  299,  299,  299,  299,  299,  299,
      299,  299,  299,  299,  299,  299,  299,  299,  299,  299,
      299,  183,  171,    1,    0,    0,    2,    0,    0,    0,
        0,    0,   20,   19,   23,   22,    0,  193,    0,    0,
        0,    0,  192,    0,  194,    0,    0,    0,    0,    0,
      195,  186,  179,  180,  299,  202,  299,  299,  299,  299,

      299,  299,  299,  299,  299,  299,  299,  299,  299,  299,
      299,  299,  299,  299,  299,  299,  299,  299,  299,  299,
      299,  299,  299,   39,  299,  299,  299,  299,  299,  299,
      299,  299,  299,  299,  299,   32,  299,  299,  299,  299,
      299,  299,  299,  299,  299,  299,  299,   69,  299,  299,
      299,  299,  299,  299,  299,  299,  299,  299,  299,  299,
      299,  299,  299,  299,  299,  299,  299,  299,  299,  299,
      299,  299,  299,  299,  299,  299,  299,  299,  299,  299,
      299,  299,  299,  299,  299,  299,  299,    0,    0,    0,
        0,    0,   19,    0,  193,  189,  197,    0,  192,    0,

        0,    0,    0,    0,  194,  190,  198,  195,    0,    0,
        0,    0,  186,  186,  186,  299,  299,  299,   30,  299,
      299,  299,  260,  253,  299,  299,  299,  299,  299,  299,
      299,  299,  299,  299,  299,  299,   38,  205,  299,  299,
      299,  299,  299,  299,   76,  299,  299,  210,  223,  299,
      299,  299,  299,  299,  299,  299,  299,  299,  299,  299,
      299,  299,  299,  220,  256,   56,   57,   58,  299,  299,
      299,  299,  299,  299,  299,  299,  299,  299,  299,  299,
      299,  299,  299,  299,  299,  299,  299,  299,  299,  299,
      299,  299,  299,  299,  299,  299,  208,  200,  299,  299,

      299,   33,  299,  299,  299,  299,  299,  299,  299,   53,
       54,   55,  162,  299,  299,  299,    0,    0,    0,    0,
        0,    0,  192,  188,  196,  191,  199,  299,  299,  299,
       34,  299,   44,   45,   46,  299,  203,  299,  299,   29,
      299,  299,  299,  299,  234,  235,  236,  299,  231,  232,
      233,  299,  299,  299,  201,  299,  224,   31,  246,  247,
      248,  258,  228,  229,  230,  299,  299,  299,  299,   70,
      226,  299,  299,  299,  299,   47,   48,   49,  299,  299,
      299,  299,  299,  299,  299,  299,  299,  299,  299,   79,
      299,  299,  299,  299,  299,  299,  299,  299,  299,  299,

      221,  299,  299,  299,  299,  299,  299,  299,  299,  299,
      299,  299,  299,  299,  299,  204,  299,  299,  255,   50,
       51,   52,  299,  299,   37,  299,    0,    0,    0,    0,
        0,  263,  299,  299,   72,  299,  299,  261,  299,  299,
       43,  299,  299,  299,  299,  222,  217,  299,  299,  266,
      299,  299,  299,  299,  299,  299,  299,  299,  213,  299,
      299,  299,  299,  163,   59,   60,   61,   62,   63,   64,
       65,   66,   67,  299,  299,  299,  299,  227,  209,  299,
      299,  299,  215,  299,  299,  299,   42,  299,  273,  158,
      252,   77,  216,  161,  299,  264,  211,  299,  299,  299,

      299,  299,  299,  299,  299,  299,  299,  299,  299,    0,
        0,    0,    0,    0,  299,  299,  299,  299,  299,  212,
       41,  237,  238,  239,  240,  241,  242,  243,  244,  245,
      299,  287,  288,  289,  284,  285,  286,  299,  276,  277,
      278,  299,  299,  299,  299,  299,  115,  116,  117,  299,
      299,  275,  299,  299,  299,  257,  299,  299,  299,  299,
      299,  114,  299,  299,  299,  299,  299,  299,  299,  299,
      299,  206,  280,  281,  282,  299,  299,  299,  299,  299,
      299,   71,  299,  299,   73,  299,  299,    0,    0,    0,
        0,    0,    0,  299,  299,   74,  152,   35,  218,  299,

      299,  299,  299,  126,  127,  128,  299,  299,  299,  299,
      299,  299,  299,  299,  299,  299,  299,  299,  299,  299,
      214,  299,  299,  299,  299,  155,  272,  154,  299,  299,
      299,  299,  299,  299,  299,  299,  299,  207,  137,  138,
      139,  299,  299,  279,  225,  299,  153,  299,    0,    5,
        0,    8,    0,    0,    0,   16,    3,  299,   28,  290,
      291,  292,  293,  294,  295,  296,  297,  298,  283,  299,
      299,  299,  299,  299,  299,  299,  299,  299,  124,  299,
      299,  299,  119,  219,   75,  299,  299,  299,  299,  299,
      254,  299,  262,  299,  259,  267,   80,   81,   82,  299,

      299,  299,  299,  299,  299,  299,  299,  299,  299,  299,
      299,  299,  299,  299,  299,  156,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  299,  299,  299,  135,  299,
      299,  130,  299,  299,  299,  299,  299,  299,  299,  299,
       91,   92,   93,  299,  299,  299,  299,  299,  299,  299,
      299,  299,  299,  299,  299,  299,  299,  274,  299,  299,
      299,  146,  299,  299,  141,   97,   98,   99,  299,  299,
        4,    0,    0,    0,    6,    0,    0,    0,    0,    0,
        0,    0,  157,  299,  299,  299,  299,  299,  299,  299,
      299,  299,  299,  118,  299,  120,  299,  299,  299,  299,

      299,  299,  299,  299,  299,  299,  299,  299,  103,  299,
      299,  299,  299,   83,  299,  299,  299,  299,  299,  299,
      299,  299,  299,  299,  299,  299,  299,  299,    0,    7,
        0,    0,    0,    0,    0,  299,  299,  299,  129,  131,
      299,  121,  299,  122,  299,  299,  299,  299,  299,  104,
      299,  299,   94,  299,  299,  299,  299,  299,  299,  299,
      299,  299,  299,  299,  299,  299,  299,  299,  299,  299,
      140,  142,  299,  299,  299,  105,  299,  299,  100,    0,
        0,    0,    0,  132,  133,  299,  299,  299,  148,  299,
      299,  149,  299,  299,  299,  299,  299,  299,  299,   78,

      299,  299,  299,  299,  299,  249,  299,  250,  265,  299,
      299,  299,  299,  143,  144,  299,  299,  299,  299,  299,
      299,  299,  299,    0,    0,    0,    0,  299,  299,  299,
      299,  125,  123,  299,  299,  299,  268,  270,  299,  299,
       84,  299,   85,  299,  299,  299,  299,  299,  299,  299,
      299,  299,  299,  299,  299,  269,  271,  299,    0,    0,
        0,    0,    0,  136,  134,  299,  299,   95,   96,  299,
      299,  160,  299,   86,  299,  299,  299,   87,  299,  299,
      299,  299,  147,  145,  101,  102,  299,  299,    0,    0,
        0,    0,    0,  299,  299,  299,  299,  299,  299,  106,

      299,  109,  299,  299,  299,  299,  299,    0,    0,    0,
        0,    0,    0,  299,  299,  107,  110,  299,  299,  299,
      299,   88,  299,  299,  108,  111,    0,    0,    0,    9,
        0,    0,    0,    0,  150,  151,  299,  299,  299,  299,
      113,  299,    0,    0,   10,    0,    0,    0,    0,  299,
      299,  251,  299,  299,    0,    0,    0,    0,    0,   13,
       89,   90,  299,  159,    0,    0,    0,   11,    0,   14,
      299,    0,    0,   12,  112,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   15,    0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    6,    7,    8,    1,    9,   10,    1,   11,
       12,   13,   14,    1,   15,   16,   17,   18,   19,   20,
       21,   22,   23,   24,   23,   25,   25,   26,    1,   27,
       28,   29,    1,    1,   30,   31,   32,   33,   34,   35,
       36,   37,   38,   38,   38,   39,   40,   38,   41,   42,
       38,   43,   44,   45,   46,   38,   38,   47,   38,   38,
        1,    1,    1,   48,   49,    1,   50,   51,   52,   53,

       54,   55,   56,   57,   58,   59,   60,   61,   62,   63,
       64,   65,   38,   66,   67,   68,   69,   70,   71,   72,
       73,   74,    1,   75,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[76] =
    {   0,
        1,    1,    2,    1,    3,    1,    3,    1,    1,    1,
        1,    1,    1,    1,    1,    3,    3,    4,    4,    4,
        4,    4,    4,    4,    4,    1,    1,    1,    1,    4,
        4,    4,    4,    4,    4,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    1,    5,    4,
        4,    4,    4,    4,    4,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    1
    } ;

static const flex_int16_t yy_base[1195] =
    {   0,
        0,   74,   82,    0, 1707, 1706, 1708, 1711,   76, 1711,
     1679, 1678,  148, 1677,  145,  146,  144, 1676,  161,  218,
      143, 1675,  159,    0,  144,  123,  132,  149,  162,  151,
      198, 1638,  139,  203,  154,  171,  155, 1632,  181,  190,
      224,  234,  227,  199,  189,  200,  294,  275, 1711,  299,
     1711, 1683, 1711,  290, 1711,    0, 1711, 1711,  314, 1711,
     1711, 1711, 1711, 1711, 1711, 1711, 1711, 1711,  328, 1711,
      372,  258,  350,  398, 1711, 1660,    0, 1637,    0, 1711,
     1658, 1635, 1667, 1711, 1711, 1711, 1666,    0, 1711, 1711,
     1625, 1630,  203, 1627, 1636, 1634, 1634, 1620, 1623, 1635,

      260,  214, 1617, 1633, 1613, 1627, 1613, 1610, 1610, 1653,
     1615,  259,  271, 1609, 1620, 1605, 1611, 1615, 1616, 1647,
        0, 1606, 1617,  273, 1616, 1611, 1591,  261, 1595, 1609,
     1599,  296, 1592,  276, 1593, 1604, 1606,  289, 1585, 1593,
      314, 1580, 1589,  128,  335, 1594, 1584, 1588, 1591, 1579,
     1582, 1624,  263,  321,  352, 1591, 1578, 1591,  297, 1584,
     1583, 1711, 1711,  426,  396,  433, 1711, 1568, 1576, 1580,
     1571, 1582,  435,    0,  423,    0,  449, 1711, 1600, 1599,
     1578, 1577,  421,  486, 1711, 1596, 1595, 1574, 1573,  494,
      502,  489, 1711, 1711, 1569,    0, 1564, 1559, 1563, 1573,

     1567, 1569,  397, 1552, 1552, 1564, 1555,  292, 1566, 1551,
     1562, 1545, 1561, 1559, 1556, 1547, 1554,  362, 1540, 1538,
     1551, 1536, 1553,    0, 1550, 1537, 1545, 1542, 1546, 1527,
     1546, 1539, 1536, 1524, 1523,  425, 1541, 1528, 1537, 1524,
     1531, 1521,  463, 1527, 1530, 1520, 1528, 1516, 1520, 1511,
     1526, 1512, 1524, 1514, 1521,  312, 1504, 1523, 1506, 1504,
     1503, 1514, 1503, 1498, 1496, 1498, 1509, 1494, 1501, 1495,
     1492, 1504, 1503, 1486, 1505, 1486,  350, 1495, 1490, 1488,
     1498, 1476,  468, 1495, 1497, 1485, 1477, 1476, 1491, 1479,
     1491, 1474,    0,  524,  546, 1711, 1711,  572, 1711, 1504,

     1503, 1482, 1481,  554,  590, 1711, 1711, 1711, 1500, 1499,
     1478, 1477, 1711, 1492, 1469, 1459, 1470, 1469,    0, 1466,
     1471,  475,    0,    0, 1458, 1456, 1456, 1457, 1452, 1461,
     1449, 1449, 1466,  509, 1454,  512,    0,    0, 1448, 1463,
     1458, 1457, 1456, 1456,    0, 1440,  531,    0,    0, 1442,
      534, 1452, 1449, 1450, 1440, 1434, 1433, 1478, 1433, 1432,
     1432,  540, 1427,    0,    0, 1423, 1422, 1421, 1423, 1424,
     1429, 1423, 1419, 1433, 1428, 1428, 1418, 1425, 1424, 1417,
     1411, 1413, 1412, 1415, 1415, 1421, 1406, 1409, 1404, 1413,
     1418, 1405, 1402, 1415, 1424, 1404,    0,    0, 1411, 1409,

     1406, 1437, 1396, 1396, 1402, 1392, 1400,  578, 1397,    0,
        0,    0,    0, 1386, 1399, 1398, 1397, 1389, 1395, 1392,
     1380,  598,  634, 1711, 1711, 1711, 1711, 1392, 1393, 1393,
        0, 1377,    0,    0,    0, 1378,    0, 1387, 1377,    0,
     1376, 1377, 1383, 1370, 1363, 1362, 1361, 1378,    0,    0,
        0, 1368, 1362, 1377,    0, 1362,    0, 1408,    0,    0,
        0,    0,    0,    0,    0, 1374, 1371,  611, 1370,    0,
        0, 1374, 1367, 1363, 1359,    0,    0,    0, 1351,  584,
      613,  616, 1356, 1352, 1358, 1348, 1346, 1360, 1344,    0,
     1353, 1343, 1357, 1345, 1341, 1348, 1342, 1354, 1349, 1349,

        0, 1346, 1343, 1347, 1330, 1328, 1331, 1338, 1344, 1343,
     1338, 1339, 1336, 1367, 1322,    0, 1324, 1325,    0,    0,
        0,    0, 1322, 1326,    0, 1319, 1319, 1312,  457, 1318,
     1321,    0, 1329, 1308,    0, 1318, 1312,    0, 1305, 1305,
        0, 1319,  619,  628,  640,    0, 1321,  643,  646,    0,
     1346,  654,  661, 1336, 1335, 1334, 1297, 1296,    0, 1296,
     1313, 1312, 1307,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0, 1295, 1309, 1295, 1292,    0,    0, 1298,
     1293,  323,    0, 1293, 1301, 1300,    0, 1292, 1284,    0,
        0,    0,    0,    0, 1281,    0,    0, 1275, 1279, 1291,

      657,  665, 1296, 1282, 1289, 1288, 1285, 1279, 1276, 1271,
     1284,  685, 1286, 1271, 1265, 1265, 1279, 1263, 1276,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
     1268, 1256, 1255, 1254,    0,    0,    0, 1276,    0,    0,
        0, 1291, 1290, 1289, 1252, 1251,  558,  658,    0, 1264,
     1267,    0, 1265, 1253, 1249,    0, 1262, 1259, 1258, 1247,
     1252,    0, 1245, 1235, 1253, 1238, 1241,  692, 1246, 1242,
     1248,    0,    0,    0,    0, 1268, 1267, 1266, 1229, 1228,
     1228,    0, 1242, 1228,    0, 1239, 1231, 1233, 1236,  725,
      713,  475, 1226, 1230, 1233,    0,    0,    0,    0,  699,

      719,  730, 1218, 1255,  723,    0, 1229, 1232, 1216, 1224,
     1214, 1235, 1224, 1220, 1221, 1221, 1220, 1205,  736, 1218,
        0, 1219, 1207, 1201, 1205,    0,    0,    0, 1201, 1233,
     1232, 1231, 1194, 1193, 1189, 1197, 1195,    0, 1228,  730,
        0, 1202, 1205,    0,    0,  755,    0, 1182, 1190, 1711,
      796, 1711,  759,    0,  786,  788, 1711, 1190,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0, 1186,
     1185, 1206, 1195, 1187, 1176, 1162, 1177, 1160, 1195, 1172,
     1173, 1168, 1191,    0,    0, 1187, 1186, 1185, 1148, 1147,
        0, 1147,    0, 1156,    0,    0,  670,  782, 1170, 1157,

     1160, 1142, 1155, 1158, 1141, 1140, 1161, 1150, 1148, 1148,
     1168, 1167, 1166, 1127, 1126,    0, 1131, 1186,  858,  825,
      831, 1147,   23,   95,  143,  138,  145,  163,  215,  208,
      229,  259,  256,  274,  337,  337,  340,  362,  359,  386,
      423,  799,    0,  426,  435,  434,  423,  433,  445,  470,
      494,  486,  523,  528,  529,  535,  570,    0,  573,  562,
      578,  616,  618,  618,  653,  664,  824,    0,  644,  666,
     1711,  715,  835,  853, 1711,  866,    0,  889,  692,  678,
      674,  688,    0,  708,  709,  699,  701,  705,  718,  712,
      728,  721,  729,    0,  732,    0,  734,  736,  747,  779,

      770,  776,  781,  781,  799,  791,  812,  799,  836,  818,
      822,  821,  820,  853,  809,  849,  845,  846,  832,  831,
      834,  835,  836,  837,  860,  852,  860,  862,  915, 1711,
      919,  883,  854,  867,  863,  854,  855,  863,    0,    0,
      865,  888,  862,  890,  885,  865,  887,  872,  873,  910,
      889,  888,  913,  890,  911,  896,  894,  898,  883,  882,
      898,  884,  887,  888,  898,  893,  900,  885,  886,  894,
        0,    0,  895,  896,  897,  934,  913,  912,  937,  929,
      913,  908,  913,    0,    0,  922,  923,  917,    0,  918,
      903,    0,  904,  928,  929,  914,  913,  916,  917,    0,

      937,  912,  922,  914,  922,  945,  926,    0,    0,  925,
      942,  943,  944,    0,    0,  945,  946,  947,  948,  933,
      932,  935,  936, 1001, 1002,  947,  945,  936,  937,  961,
      962,    0,    0,  941,  942,  950,    0,    0,  951,  973,
      975,  949,  977,  972,  966,  953,  975,  973,  966,  962,
      956,  957,  958,  959,  967,    0,    0,  968, 1033, 1034,
     1035,  967,  986,    0,    0,  990,  991,    0,    0,  996,
      997,    0,  991,    0,  992,  977, 1001,    0,  979,  989,
     1013, 1001,    0,    0,    0,    0, 1006, 1007,  995, 1057,
     1005, 1007, 1061, 1000, 1001,  994,  996, 1020, 1021,    0,

     1020, 1030, 1004, 1042, 1024, 1005, 1006, 1010, 1026, 1080,
     1082, 1084, 1092, 1012, 1017,    0,    0, 1037, 1043, 1034,
     1043,    0, 1057, 1068,    0,    0, 1053, 1102, 1103, 1711,
     1107, 1108, 1114, 1062,    0,    0, 1042, 1047, 1049, 1072,
        0, 1076, 1058, 1124, 1711, 1125, 1076, 1073, 1130, 1062,
     1063,    0, 1084, 1093, 1082, 1086, 1141, 1142, 1143, 1711,
        0,    0, 1085,    0, 1100, 1155, 1156, 1711, 1157, 1711,
     1080, 1089, 1161, 1711,    0, 1096, 1169, 1174, 1179, 1181,
     1104, 1109, 1185, 1186, 1711, 1711, 1231, 1233, 1235, 1171,
     1240, 1173, 1243, 1178

    } ;

static const flex_int16_t yy_def[1195] =
    {   0,
     1186,    1, 1186,    3, 1187, 1187, 1186, 1186, 1186, 1186,
     1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186,
     1186, 1186, 1186, 1188, 1186, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1186, 1186, 1186, 1186, 1186,
     1186, 1186, 1186, 1186, 1186, 1189, 1186, 1186, 1186, 1186,
     1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186,
     1186,   19, 1186, 1186, 1186, 1186, 1190, 1186,   20, 1186,
     1186, 1186, 1186, 1186, 1186, 1186, 1186, 1188, 1186, 1186,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,

     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186,
     1186, 1186, 1186, 1191, 1186, 1189, 1186, 1186, 1186, 1186,
     1186, 1186,   71, 1186, 1186, 1186, 1186, 1186, 1186, 1186,
     1186, 1190, 1186, 1186, 1188, 1188, 1188, 1188, 1188, 1188,

     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1186, 1186, 1186,
     1186, 1186, 1191, 1186, 1186, 1186, 1186, 1186, 1186, 1186,

     1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186,
     1186, 1186, 1186, 1186, 1186, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,

     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1186, 1186, 1186, 1186,
     1186, 1186, 1186, 1186, 1186, 1186, 1186, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,

     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1186, 1186, 1186, 1186,
     1186, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,

     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1186,
     1186, 1186, 1186, 1186, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1186, 1186, 1186,
     1186, 1186, 1186, 1188, 1188, 1188, 1188, 1188, 1188, 1188,

     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1186, 1186,
     1186, 1186, 1186, 1192, 1186, 1186, 1186, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,

     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1186, 1193, 1186, 1186,
     1192, 1186, 1186, 1186, 1186, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1186, 1193, 1186, 1186, 1186, 1186, 1194, 1186, 1186, 1186,
     1186, 1186, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,

     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1186, 1186,
     1194, 1186, 1186, 1186, 1186, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1186,
     1186, 1186, 1186, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,

     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1186, 1186, 1186, 1186, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1186, 1186,
     1186, 1186, 1186, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1188, 1186, 1186,
     1186, 1186, 1186, 1188, 1188, 1188, 1188, 1188, 1188, 1188,

     1188, 1188, 1188, 1188, 1188, 1188, 1188, 1186, 1186, 1186,
     1186, 1186, 1186, 1188, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1188, 1188, 1188, 1188, 1186, 1186, 1186, 1186,
     1186, 1186, 1186, 1186, 1188, 1188, 1188, 1188, 1188, 1188,
     1188, 1188, 1186, 1186, 1186, 1186, 1186, 1186, 1186, 1188,
     1188, 1188, 1188, 1188, 1186, 1186, 1186, 1186, 1186, 1186,
     1188, 1188, 1188, 1188, 1186, 1186, 1186, 1186, 1186, 1186,
     1188, 1186, 1186, 1186, 1188, 1186, 1186, 1186, 1186, 1186,
     1186, 1186, 1186, 1186, 1186,    0, 1186, 1186, 1186, 1186,
     1186, 1186, 1186, 1186

    } ;

static const flex_int16_t yy_nxt[1787] =
    {   0,
        8,    9,   10,    9,    9,   11,    8,    8,   12,   13,
        8,    8,   14,   15,   16,   17,   18,   19,   20,   20,
       20,   20,   20,   20,   20,    8,   21,   22,   23,   24,
       24,   24,   24,   24,   24,   24,   24,   24,   24,   24,
       24,   24,   24,   24,   24,   24,   24,   25,   24,   26,
       27,   28,   29,   30,   31,   32,   33,   34,   24,   24,
       35,   36,   37,   38,   39,   40,   41,   42,   43,   44,
       45,   24,   24,   24,   46,   47,  880,   59,   47,   59,
       59,   48,   49,   50,   51,   50,   50,   49,   49,   49,
       49,   49,   49,   49,   49,   49,   49,   49,   52,   53,

       54,   54,   54,   54,   54,   54,   54,   55,   49,   49,
       49,   56,   56,   56,   56,   56,   56,   56,   56,   56,
       56,   56,   56,   56,   56,   56,   56,   56,   56,   49,
       56,   56,   56,   56,   56,   56,   56,   56,   56,   56,
       56,   56,   56,   56,   56,   56,   56,   56,   56,   56,
       56,   56,   56,   56,   56,   56,   49,   62,   65,  881,
       67,   69,   69,   69,   69,   69,   69,   69,   69,   83,
       84,   89,   66,   68,   91,   63,   71,  264,   72,   72,
       72,   72,   72,   72,   72,   73,   86,   87,  117,   92,
       93,   90,  882,  265,   74,   94,  118,   95,   98,   75,

       96,   97,   99,  127,  131,  883,   76,   77,  119,  100,
      884,  107,  101,  108,   74,  102,  110,  128,  132,  103,
      129,   75,  109,  104,  130,  105,  120,  162,  885,   78,
      134,  106,   77,   71,  135,   79,   79,   79,   79,   79,
       79,   79,   79,  138,  886,  160,  136,  111,  157,  137,
      152,   74,  158,  139,  161,  112,   80,  121,  113,  887,
      122,  114,  159,   81,  123,  124,  197,  115,  209,  125,
      198,   74,  126,  140,  163,  210,  166,  167,   80,  166,
      141,  142,  888,  147,  153,  143,   82,  148,  889,  154,
      149,  144,  145,  155,  146,  164,  156,   59,  164,  150,

      173,  165,  173,  173, 1186,  890,  151,  175,  175,  175,
      175,  175,  175,  175,  175,   59,  206,   59,   59,  220,
      222,  207,  208,  241,  275,  276,  891,  249,  168, 1186,
      221,  242,  169,  233,  223,  170,  234,  235,  255,  171,
      236,  250,  237,  251,  172,   69,   69,   69,   69,   69,
       69,   69,   69,  246,  284,  256,  257,  285,  329,  330,
      247,  177,  178,  260,  179,   71,  180,   73,   73,   73,
       73,   73,   73,   73,   73,  381,  662,  261,  277,  382,
      663,  177,  178,   74,  181,  266,  892,  278,  182,  183,
      183,  183,  183,  183,  183,  183,  183,  166,  167,  267,

      166,  279,  893,   74,  403,  184,  185,  894,  186,  280,
      187,  190,  190,  404,  895,  191,  191,  191,  191,  191,
      191,  191,  191,  340,  896,  184,  185,  164,  188,   59,
      164,  341,  189,  165,  166,  167,  173,  166,  173,  173,
      175,  175,  175,  175,  175,  175,  175,  175,  358,  168,
      323,  897,  898,  169,  298,  299,  170,  300,  612,  301,
      171,  612,  294,  294,  324,  172,  295,  295,  295,  295,
      295,  295,  295,  295,  298,  299,  756,  302,  359,  756,
      902,  303,  366,  367,  368,  903,  168,  410,  411,  412,
      169,  904,  905,  170,  433,  434,  435,  171,  906,  304,

      304,  907,  172,  305,  305,  305,  305,  305,  305,  305,
      305,  191,  191,  191,  191,  191,  191,  191,  191,  191,
      191,  191,  191,  191,  191,  191,  191,  313,  445,  446,
      447,  449,  450,  451,  314,  908,  308,  909,  309,  910,
      310,  295,  295,  295,  295,  295,  295,  295,  295,  313,
      459,  460,  461,  463,  464,  465,  308,  315,  311,  476,
      477,  478,  312,  295,  295,  295,  295,  295,  295,  295,
      295,  305,  305,  305,  305,  305,  305,  305,  305,  911,
      178,  912,  179,  913,  180,  422,  422,  709,  914,  423,
      423,  423,  423,  423,  423,  423,  423,  520,  521,  522,

      178,  710,  181,  565,  566,  567,  182,  305,  305,  305,
      305,  305,  305,  305,  305,  423,  423,  423,  423,  423,
      423,  423,  423,  915,  185,  916,  186,  917,  187,  554,
      555,  556,  568,  569,  570,  571,  572,  573,  622,  623,
      624,  557,  558,  918,  185,  919,  188,  625,  626,  627,
      189,  423,  423,  423,  423,  423,  423,  423,  423,  628,
      629,  630,  632,  633,  634,  635,  636,  637,  299,  920,
      300,  921,  301,  639,  640,  641,  673,  674,  675,  642,
      643,  644,  922,  676,  677,  678,  612,  711,  299,  612,
      302,  645,  646,  923,  303,  679,  680,  712,  927,  848,

      713,  714,  690,  691,  691,  691,  691,  691,  691,  691,
      730,  731,  732,  849,  751,  752,  928,  751,  760,  761,
      762,  873,  733,  734,  932,  735,  751,  752,  933,  751,
      755,  755,  755,  755,  755,  755,  755,  755,  763,  764,
      765,  934,  753,  753,  753,  753,  753,  753,  753,  766,
      767,  768,  771,  935,  786,  787,  788,  936,  937,  806,
      751,  752,  772,  751,  938,  773,  789,  790,  939,  807,
      940,  754,  808,  811,  812,  813,  753,  753,  753,  753,
      753,  753,  753,  941,  942,  814,  815,  751,  752,  756,
      751,  943,  756,  944,  945,  946,  754,  751,  752,  947,

      751,  948,  818,  755,  755,  755,  755,  755,  755,  755,
      755,  850,  949,  819,  820,  820,  820,  820,  820,  820,
      820,  851,  950,  951,  852,  853,  874,  875,  899,  874,
      952,  822,  751,  752,  953,  751,  929,  930,  900,  929,
      823,  901,  878,  878,  878,  878,  878,  878,  878,  878,
      954,  824,  955,  924,  874,  875,  956,  874,  825,  874,
      875,  957,  874,  925,  958,  959,  926,  874,  875,  960,
      874,  961,  962,  963,  966,  876,  876,  876,  876,  876,
      876,  876,  964,  876,  876,  876,  876,  876,  876,  876,
      874,  875,  967,  874,  968,  969,  965,  970,  971,  972,

      973,  974,  975,  976,  877,  977,  878,  878,  878,  878,
      878,  878,  878,  878,  978,  979,  929,  930,  980,  929,
      874,  875,  981,  874,  982,  983,  984,  985,  986,  877,
      987,  988,  989,  990,  991,  992,  993,  994,  995,  996,
      997,  998,  999, 1000, 1001, 1002, 1003, 1004, 1005, 1006,
     1007, 1008, 1009, 1010, 1011, 1012, 1013, 1014, 1015, 1016,
     1017, 1018, 1019, 1020, 1021, 1022, 1023, 1024, 1025, 1026,
     1027, 1028, 1029, 1030, 1031, 1032, 1033, 1034, 1035, 1036,
     1037, 1038, 1039, 1040, 1041, 1042, 1043, 1044, 1045, 1046,
     1047, 1048, 1049, 1050, 1051, 1052, 1053, 1054, 1055, 1056,

     1057, 1058, 1059, 1060, 1062, 1059, 1060, 1063, 1064, 1065,
     1066, 1067, 1061, 1068, 1069, 1070, 1071, 1072, 1073, 1074,
     1075, 1076, 1077, 1078, 1079, 1080, 1081, 1082, 1083, 1084,
     1085, 1086, 1087, 1088, 1059, 1060, 1090, 1059, 1060, 1090,
     1092, 1093, 1094, 1095, 1061, 1096, 1097, 1098, 1099, 1100,
     1101, 1102, 1103, 1104, 1105, 1106, 1107, 1108, 1090, 1109,
     1111, 1090, 1112, 1114, 1115, 1112, 1116, 1110, 1117, 1118,
     1119, 1113, 1120, 1121, 1122, 1123, 1124, 1125, 1126, 1127,
     1128, 1129, 1135, 1131, 1129, 1112, 1131, 1136, 1112, 1137,
     1089, 1130, 1132, 1133, 1113, 1138, 1133, 1139, 1091, 1140,

     1141, 1142, 1143, 1144, 1129, 1150, 1144, 1129, 1131, 1146,
     1151, 1131, 1146, 1145, 1130, 1133, 1148, 1132, 1133, 1152,
     1091, 1153, 1154, 1155, 1149, 1144, 1146, 1158, 1144, 1146,
     1156, 1159, 1161, 1162, 1159, 1145, 1163, 1164, 1157, 1165,
     1166, 1160, 1167, 1169, 1159, 1167, 1169, 1159, 1171, 1172,
     1175, 1176, 1168, 1170, 1160, 1134, 1173, 1167, 1169, 1173,
     1167, 1169, 1173, 1177, 1182, 1173, 1174, 1168, 1170, 1183,
     1178, 1147, 1174, 1178,  192, 1178,  821, 1134, 1178, 1179,
     1180,  931, 1180, 1180, 1179, 1180, 1184, 1184, 1147, 1184,
     1184,  879,  873,  871,  870,  869, 1185, 1185,  868,  867,

      866,  865,  864,  863,  862,  861,  860,  859,  858,  857,
      856,  855,  854,  847,  846,  845,  844,  843,  842,  841,
      840,  839,  838,  837,  836,  835,  834,  833, 1181,  832,
     1181,   57,   57,   57,   57,   57,   88,   88,  176,  176,
      293,  831,  293,  293,  293,  872,  872,  872,  830,  829,
      828,  827,  826,  817,  816,  810,  809,  805,  804,  803,
      802,  801,  800,  799,  798,  797,  796,  795,  794,  793,
      792,  791,  785,  784,  783,  782,  781,  780,  779,  778,
      777,  776,  775,  774,  770,  769,  759,  758,  757,  750,
      749,  748,  747,  746,  745,  744,  743,  742,  741,  740,

      739,  738,  737,  736,  729,  728,  727,  726,  725,  724,
      723,  722,  721,  720,  719,  718,  717,  716,  715,  708,
      707,  706,  705,  704,  703,  702,  701,  700,  699,  698,
      697,  696,  695,  694,  693,  692,  689,  688,  687,  686,
      685,  684,  683,  682,  681,  672,  671,  670,  669,  668,
      667,  666,  665,  664,  661,  660,  659,  658,  657,  656,
      655,  654,  653,  652,  651,  650,  649,  648,  647,  638,
      631,  621,  620,  619,  618,  617,  616,  615,  614,  613,
      611,  610,  609,  608,  607,  606,  605,  604,  603,  602,
      601,  600,  599,  598,  597,  596,  595,  594,  593,  592,

      591,  590,  589,  588,  587,  586,  585,  584,  583,  582,
      581,  580,  579,  578,  577,  576,  575,  574,  564,  563,
      562,  561,  560,  559,  553,  552,  551,  550,  549,  548,
      547,  546,  545,  544,  543,  542,  541,  540,  539,  538,
      537,  536,  535,  534,  533,  532,  531,  530,  529,  528,
      527,  526,  525,  524,  523,  519,  518,  517,  516,  515,
      514,  513,  512,  511,  510,  509,  508,  507,  506,  505,
      504,  503,  502,  501,  500,  499,  498,  497,  496,  495,
      494,  493,  492,  491,  490,  489,  488,  487,  486,  485,
      484,  483,  482,  481,  480,  479,  475,  474,  473,  472,

      471,  470,  469,  468,  467,  466,  462,  458,  457,  456,
      455,  454,  453,  452,  448,  444,  443,  442,  441,  440,
      439,  438,  437,  436,  432,  431,  430,  429,  428,  313,
      313,  427,  426,  427,  426,  425,  424,  425,  424,  421,
      420,  419,  418,  417,  416,  415,  414,  413,  409,  408,
      407,  406,  405,  402,  401,  400,  399,  398,  397,  396,
      395,  394,  393,  392,  391,  390,  389,  388,  387,  386,
      385,  384,  383,  380,  379,  378,  377,  376,  375,  374,
      373,  372,  371,  370,  369,  365,  364,  363,  362,  361,
      360,  357,  356,  355,  354,  353,  352,  351,  350,  349,

      348,  347,  346,  345,  344,  343,  342,  339,  338,  337,
      336,  335,  334,  333,  332,  331,  328,  327,  326,  325,
      322,  321,  320,  319,  318,  317,  316,  307,  306,  307,
      306,  297,  296,  297,  296,  292,  291,  290,  289,  288,
      287,  286,  283,  282,  281,  274,  273,  272,  271,  270,
      269,  268,  263,  262,  259,  258,  254,  253,  252,  248,
      245,  244,  243,  240,  239,  238,  232,  231,  230,  229,
      228,  227,  226,  225,  224,  219,  218,  217,  216,  215,
      214,  213,  212,  211,  205,  204,  203,  202,  201,  200,
      199,  196,  195,  194,  193,   80,   80,   75,   75,  174,

      133,  116,   85,   70,   64,   61,   60, 1186,   58,   58,
        7, 1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186,
     1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186,
     1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186,
     1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186,
     1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186,
     1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186,
     1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186,
     1186, 1186, 1186, 1186, 1186, 1186
    } ;

static const flex_int16_t yy_chk[1787] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    2,  823,    9,    2,    9,
        9,    2,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,

        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,   13,   15,  824,
       16,   17,   17,   17,   17,   17,   17,   17,   17,   21,
       21,   25,   15,   16,   26,   13,   19,  144,   19,   19,
       19,   19,   19,   19,   19,   19,   23,   23,   33,   26,
       26,   25,  825,  144,   19,   27,   33,   27,   28,   19,

       27,   27,   28,   35,   37,  826,   19,   19,   33,   28,
      827,   30,   28,   30,   19,   29,   31,   35,   37,   29,
       36,   19,   30,   29,   36,   29,   34,   46,  828,   19,
       39,   29,   19,   20,   39,   20,   20,   20,   20,   20,
       20,   20,   20,   40,  829,   45,   39,   31,   44,   39,
       43,   20,   44,   40,   45,   31,   20,   34,   31,  830,
       34,   31,   44,   20,   34,   34,   93,   31,  102,   34,
       93,   20,   34,   41,   46,  102,   48,   48,   20,   48,
       41,   41,  831,   42,   43,   41,   20,   42,  832,   43,
       42,   41,   41,   43,   41,   47,   43,   47,   47,   42,

       50,   47,   50,   50,   72,  833,   42,   54,   54,   54,
       54,   54,   54,   54,   54,   59,  101,   59,   59,  112,
      113,  101,  101,  128,  153,  153,  834,  134,   48,   72,
      112,  128,   48,  124,  113,   48,  124,  124,  138,   48,
      124,  134,  124,  134,   48,   69,   69,   69,   69,   69,
       69,   69,   69,  132,  159,  138,  138,  159,  208,  208,
      132,   69,   69,  141,   69,   73,   69,   73,   73,   73,
       73,   73,   73,   73,   73,  256,  582,  141,  154,  256,
      582,   69,   69,   73,   69,  145,  835,  154,   69,   71,
       71,   71,   71,   71,   71,   71,   71,  165,  165,  145,

      165,  155,  836,   73,  277,   71,   71,  837,   71,  155,
       71,   74,   74,  277,  838,   74,   74,   74,   74,   74,
       74,   74,   74,  218,  839,   71,   71,  164,   71,  164,
      164,  218,   71,  164,  166,  166,  173,  166,  173,  173,
      175,  175,  175,  175,  175,  175,  175,  175,  236,  165,
      203,  840,  841,  165,  183,  183,  165,  183,  529,  183,
      165,  529,  177,  177,  203,  165,  177,  177,  177,  177,
      177,  177,  177,  177,  183,  183,  692,  183,  236,  692,
      844,  183,  243,  243,  243,  845,  166,  283,  283,  283,
      166,  846,  847,  166,  322,  322,  322,  166,  848,  184,

      184,  849,  166,  184,  184,  184,  184,  184,  184,  184,
      184,  190,  190,  190,  190,  190,  190,  190,  190,  191,
      191,  191,  191,  191,  191,  191,  191,  192,  334,  334,
      334,  336,  336,  336,  192,  850,  191,  851,  191,  852,
      191,  294,  294,  294,  294,  294,  294,  294,  294,  192,
      347,  347,  347,  351,  351,  351,  191,  192,  191,  362,
      362,  362,  191,  295,  295,  295,  295,  295,  295,  295,
      295,  304,  304,  304,  304,  304,  304,  304,  304,  853,
      295,  854,  295,  855,  295,  298,  298,  647,  856,  298,
      298,  298,  298,  298,  298,  298,  298,  408,  408,  408,

      295,  647,  295,  480,  480,  480,  295,  305,  305,  305,
      305,  305,  305,  305,  305,  422,  422,  422,  422,  422,
      422,  422,  422,  857,  305,  859,  305,  860,  305,  468,
      468,  468,  481,  481,  481,  482,  482,  482,  543,  543,
      543,  468,  468,  861,  305,  862,  305,  544,  544,  544,
      305,  423,  423,  423,  423,  423,  423,  423,  423,  545,
      545,  545,  548,  548,  548,  549,  549,  549,  423,  863,
      423,  864,  423,  552,  552,  552,  601,  601,  601,  553,
      553,  553,  865,  602,  602,  602,  612,  648,  423,  612,
      423,  553,  553,  866,  423,  602,  602,  648,  869,  797,

      648,  648,  612,  612,  612,  612,  612,  612,  612,  612,
      668,  668,  668,  797,  691,  691,  870,  691,  700,  700,
      700,  872,  668,  668,  879,  668,  690,  690,  880,  690,
      691,  691,  691,  691,  691,  691,  691,  691,  701,  701,
      701,  881,  690,  690,  690,  690,  690,  690,  690,  702,
      702,  702,  705,  882,  719,  719,  719,  884,  885,  740,
      753,  753,  705,  753,  886,  705,  719,  719,  887,  740,
      888,  690,  740,  746,  746,  746,  753,  753,  753,  753,
      753,  753,  753,  889,  890,  746,  746,  755,  755,  756,
      755,  891,  756,  892,  893,  895,  690,  751,  751,  897,

      751,  898,  751,  755,  755,  755,  755,  755,  755,  755,
      755,  798,  899,  751,  751,  751,  751,  751,  751,  751,
      751,  798,  900,  901,  798,  798,  820,  820,  842,  820,
      902,  756,  821,  821,  903,  821,  873,  873,  842,  873,
      756,  842,  820,  820,  820,  820,  820,  820,  820,  820,
      904,  756,  905,  867,  874,  874,  906,  874,  756,  819,
      819,  907,  819,  867,  908,  909,  867,  876,  876,  910,
      876,  911,  912,  913,  915,  819,  819,  819,  819,  819,
      819,  819,  914,  876,  876,  876,  876,  876,  876,  876,
      878,  878,  916,  878,  917,  918,  914,  919,  920,  921,

      922,  923,  924,  925,  819,  926,  878,  878,  878,  878,
      878,  878,  878,  878,  927,  928,  929,  929,  932,  929,
      931,  931,  933,  931,  934,  935,  936,  937,  938,  819,
      941,  942,  943,  944,  945,  946,  947,  948,  949,  950,
      951,  952,  953,  954,  955,  956,  957,  958,  959,  960,
      961,  962,  963,  964,  965,  966,  967,  968,  969,  970,
      973,  974,  975,  976,  977,  978,  979,  980,  981,  982,
      983,  986,  987,  988,  990,  991,  993,  994,  995,  996,
      997,  998,  999, 1001, 1002, 1003, 1004, 1005, 1006, 1007,
     1010, 1011, 1012, 1013, 1016, 1017, 1018, 1019, 1020, 1021,

     1022, 1023, 1024, 1025, 1026, 1024, 1025, 1027, 1028, 1029,
     1030, 1031, 1025, 1034, 1035, 1036, 1039, 1040, 1041, 1042,
     1043, 1044, 1045, 1046, 1047, 1048, 1049, 1050, 1051, 1052,
     1053, 1054, 1055, 1058, 1059, 1060, 1061, 1059, 1060, 1061,
     1062, 1063, 1066, 1067, 1060, 1070, 1071, 1073, 1075, 1076,
     1077, 1079, 1080, 1081, 1082, 1087, 1088, 1089, 1090, 1091,
     1092, 1090, 1093, 1094, 1095, 1093, 1096, 1091, 1097, 1098,
     1099, 1093, 1101, 1102, 1103, 1104, 1105, 1106, 1107, 1108,
     1109, 1110, 1114, 1111, 1110, 1112, 1111, 1115, 1112, 1118,
     1059, 1110, 1111, 1113, 1112, 1119, 1113, 1120, 1061, 1121,

     1123, 1124, 1127, 1128, 1129, 1137, 1128, 1129, 1131, 1132,
     1138, 1131, 1132, 1128, 1129, 1133, 1134, 1131, 1133, 1139,
     1090, 1140, 1142, 1143, 1134, 1144, 1146, 1148, 1144, 1146,
     1147, 1149, 1150, 1151, 1149, 1144, 1153, 1154, 1147, 1155,
     1156, 1149, 1157, 1158, 1159, 1157, 1158, 1159, 1163, 1165,
     1171, 1172, 1157, 1158, 1159, 1113, 1166, 1167, 1169, 1166,
     1167, 1169, 1173, 1176, 1181, 1173, 1166, 1167, 1169, 1182,
     1177, 1132, 1173, 1177, 1190, 1178, 1192, 1133, 1178, 1177,
     1179, 1194, 1180, 1179, 1178, 1180, 1183, 1184, 1146, 1183,
     1184,  822,  818,  817,  815,  814, 1183, 1184,  813,  812,

      811,  810,  809,  808,  807,  806,  805,  804,  803,  802,
      801,  800,  799,  794,  792,  790,  789,  788,  787,  786,
      783,  782,  781,  780,  779,  778,  777,  776, 1179,  775,
     1180, 1187, 1187, 1187, 1187, 1187, 1188, 1188, 1189, 1189,
     1191,  774, 1191, 1191, 1191, 1193, 1193, 1193,  773,  772,
      771,  770,  758,  749,  748,  743,  742,  739,  737,  736,
      735,  734,  733,  732,  731,  730,  729,  725,  724,  723,
      722,  720,  718,  717,  716,  715,  714,  713,  712,  711,
      710,  709,  708,  707,  704,  703,  695,  694,  693,  689,
      688,  687,  686,  684,  683,  681,  680,  679,  678,  677,

      676,  671,  670,  669,  667,  666,  665,  664,  663,  661,
      660,  659,  658,  657,  655,  654,  653,  651,  650,  646,
      645,  644,  643,  642,  638,  634,  633,  632,  631,  619,
      618,  617,  616,  615,  614,  613,  611,  610,  609,  608,
      607,  606,  605,  604,  603,  600,  599,  598,  595,  589,
      588,  586,  585,  584,  581,  580,  577,  576,  575,  574,
      563,  562,  561,  560,  558,  557,  556,  555,  554,  551,
      547,  542,  540,  539,  537,  536,  534,  533,  531,  530,
      528,  527,  526,  524,  523,  518,  517,  515,  514,  513,
      512,  511,  510,  509,  508,  507,  506,  505,  504,  503,

      502,  500,  499,  498,  497,  496,  495,  494,  493,  492,
      491,  489,  488,  487,  486,  485,  484,  483,  479,  475,
      474,  473,  472,  469,  467,  466,  458,  456,  454,  453,
      452,  448,  447,  446,  445,  444,  443,  442,  441,  439,
      438,  436,  432,  430,  429,  428,  421,  420,  419,  418,
      417,  416,  415,  414,  409,  407,  406,  405,  404,  403,
      402,  401,  400,  399,  396,  395,  394,  393,  392,  391,
      390,  389,  388,  387,  386,  385,  384,  383,  382,  381,
      380,  379,  378,  377,  376,  375,  374,  373,  372,  371,
      370,  369,  368,  367,  366,  363,  361,  360,  359,  358,

      357,  356,  355,  354,  353,  352,  350,  346,  344,  343,
      342,  341,  340,  339,  335,  333,  332,  331,  330,  329,
      328,  327,  326,  325,  321,  320,  318,  317,  316,  315,
      314,  312,  311,  310,  309,  303,  302,  301,  300,  292,
      291,  290,  289,  288,  287,  286,  285,  284,  282,  281,
      280,  279,  278,  276,  275,  274,  273,  272,  271,  270,
      269,  268,  267,  266,  265,  264,  263,  262,  261,  260,
      259,  258,  257,  255,  254,  253,  252,  251,  250,  249,
      248,  247,  246,  245,  244,  242,  241,  240,  239,  238,
      237,  235,  234,  233,  232,  231,  230,  229,  228,  227,

      226,  225,  223,  222,  221,  220,  219,  217,  216,  215,
      214,  213,  212,  211,  210,  209,  207,  206,  205,  204,
      202,  201,  200,  199,  198,  197,  195,  189,  188,  187,
      186,  182,  181,  180,  179,  172,  171,  170,  169,  168,
      161,  160,  158,  157,  156,  152,  151,  150,  149,  148,
      147,  146,  143,  142,  140,  139,  137,  136,  135,  133,
      131,  130,  129,  127,  126,  125,  123,  122,  120,  119,
      118,  117,  116,  115,  114,  111,  110,  109,  108,  107,
      106,  105,  104,  103,  100,   99,   98,   97,   96,   95,
       94,   92,   91,   87,   83,   82,   81,   78,   76,   52,

       38,   32,   22,   18,   14,   12,   11,    7,    6,    5,
     1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186,
     1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186,
     1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186,
     1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186,
     1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186,
     1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186,
     1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186, 1186,
     1186, 1186, 1186, 1186, 1186, 1186
    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "../src/compiler/glsl/glsl_lexer.ll"
#line 2 "../src/compiler/glsl/glsl_lexer.ll"
/*
 * Copyright © 2008, 2009 Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice (including the next
 * paragraph) shall be included in all copies or substantial portions of the
 * Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
#include <ctype.h>
#include <limits.h>
#include "util/strtod.h"
#include "ast.h"
#include "glsl_parser_extras.h"
#include "glsl_parser.h"
#include "main/consts_exts.h"

static int classify_identifier(struct _mesa_glsl_parse_state *, const char *,
			       unsigned name_len, YYSTYPE *output);

#ifdef _MSC_VER
#define YY_NO_UNISTD_H
#endif

#define YY_NO_INPUT
#define YY_USER_ACTION						\
   do {								\
      yylloc->first_column = yycolumn + 1;			\
      yylloc->first_line = yylloc->last_line = yylineno + 1;	\
      yycolumn += yyleng;					\
      yylloc->last_column = yycolumn + 1;			\
   } while(0);

#define YY_USER_INIT yylineno = 0; yycolumn = 0; yylloc->source = 0; \
   yylloc->path = NULL;

/* A macro for handling reserved words and keywords across language versions.
 *
 * Certain words start out as identifiers, become reserved words in
 * later language revisions, and finally become language keywords.
 * This may happen at different times in desktop GLSL and GLSL ES.
 *
 * For example, consider the following lexer rule:
 * samplerBuffer       KEYWORD(130, 0, 140, 0, SAMPLERBUFFER)
 *
 * This means that "samplerBuffer" will be treated as:
 * - a keyword (SAMPLERBUFFER token)         ...in GLSL >= 1.40
 * - a reserved word - error                 ...in GLSL >= 1.30
 * - an identifier                           ...in GLSL <  1.30 or GLSL ES
 */
#define KEYWORD(reserved_glsl, reserved_glsl_es,			\
                allowed_glsl, allowed_glsl_es, token)			\
   KEYWORD_WITH_ALT(reserved_glsl, reserved_glsl_es,			\
                    allowed_glsl, allowed_glsl_es, false, token)

/**
 * Like the KEYWORD macro, but the word is also treated as a keyword
 * if the given boolean expression is true.
 */
#define KEYWORD_WITH_ALT(reserved_glsl, reserved_glsl_es,		\
                         allowed_glsl, allowed_glsl_es,			\
                         alt_expr, token)				\
   do {									\
      if (yyextra->is_version(allowed_glsl, allowed_glsl_es)		\
          || (alt_expr)) {						\
	 return token;							\
      } else if (yyextra->is_version(reserved_glsl,			\
                                     reserved_glsl_es)) {		\
	 _mesa_glsl_error(yylloc, yyextra,				\
			  "illegal use of reserved word `%s'", yytext);	\
	 return ERROR_TOK;						\
      } else {								\
	 return classify_identifier(yyextra, yytext, yyleng, yylval);	\
      }									\
   } while (0)

/**
 * Like KEYWORD_WITH_ALT, but used for built-in GLSL types
 */
#define TYPE_WITH_ALT(reserved_glsl, reserved_glsl_es,			\
		      allowed_glsl, allowed_glsl_es,			\
		      alt_expr, gtype)					\
   do {									\
      if (yyextra->is_version(allowed_glsl, allowed_glsl_es)		\
          || (alt_expr)) {						\
	 yylval->type = gtype; 						\
	 return BASIC_TYPE_TOK;						\
      } else if (yyextra->is_version(reserved_glsl,			\
                                     reserved_glsl_es)) {		\
	 _mesa_glsl_error(yylloc, yyextra,				\
			  "illegal use of reserved word `%s'", yytext);	\
	 return ERROR_TOK;						\
      } else {								\
	 return classify_identifier(yyextra, yytext, yyleng, yylval);	\
      }									\
   } while (0)

#define TYPE(reserved_glsl, reserved_glsl_es,				\
             allowed_glsl, allowed_glsl_es,				\
             gtype)							\
   TYPE_WITH_ALT(reserved_glsl, reserved_glsl_es,			\
                 allowed_glsl, allowed_glsl_es,				\
                 false, gtype)

/**
 * A macro for handling keywords that have been present in GLSL since
 * its origin, but were changed into reserved words in later versions.
 */
#define DEPRECATED_KEYWORD(token, state, reserved_glsl,			\
                           reserved_glsl_es)				\
   do {									\
      if (yyextra->is_version(reserved_glsl, reserved_glsl_es) &&	\
          !state->compat_shader) {					\
	 _mesa_glsl_error(yylloc, yyextra,				\
			  "illegal use of reserved word `%s'", yytext);	\
	 return ERROR_TOK;						\
      } else {								\
         return token;							\
      }									\
   } while (0)

/**
 * Like DEPRECATED_KEYWORD, but for types
 */
#define DEPRECATED_ES_TYPE_WITH_ALT(alt_expr, gtype)			\
   do {									\
      if (yyextra->is_version(0, 300)) {				\
         _mesa_glsl_error(yylloc, yyextra,				\
                          "illegal use of reserved word `%s'", yytext);	\
         return ERROR_TOK;						\
      } else if (alt_expr) {						\
         yylval->type = gtype;						\
         return BASIC_TYPE_TOK;						\
      } else {								\
         return classify_identifier(yyextra, yytext, yyleng, yylval);	\
      }									\
   } while (0)

#define DEPRECATED_ES_TYPE(gtype)					\
   DEPRECATED_ES_TYPE_WITH_ALT(true, gtype)

static int
literal_integer(char *text, int len, struct _mesa_glsl_parse_state *state,
		YYSTYPE *lval, YYLTYPE *lloc, int base)
{
   bool is_uint = (text[len - 1] == 'u' ||
		   text[len - 1] == 'U');
   bool is_long = (text[len - 1] == 'l' || text[len - 1] == 'L');
   const char *digits = text;

   if (is_long)
      is_uint = (text[len - 2] == 'u' && text[len - 1] == 'l') ||
                (text[len - 2] == 'U' && text[len - 1] == 'L');
   /* Skip "0x" */
   if (base == 16)
      digits += 2;

   unsigned long long value = strtoull(digits, NULL, base);

   if (is_long)
      lval->n64 = (int64_t)value;
   else
      lval->n = (int)value;

   if (is_long && !is_uint && base == 10 && value > (uint64_t)LLONG_MAX + 1) {
      /* Tries to catch unintentionally providing a negative value. */
      _mesa_glsl_warning(lloc, state,
                         "signed literal value `%s' is interpreted as %lld",
                         text, lval->n64);
   } else if (!is_long && value > UINT_MAX) {
      /* Note that signed 0xffffffff is valid, not out of range! */
      if (state->is_version(130, 300)) {
	 _mesa_glsl_error(lloc, state,
			  "literal value `%s' out of range", text);
      } else {
	 _mesa_glsl_warning(lloc, state,
			    "literal value `%s' out of range", text);
      }
   } else if (base == 10 && !is_uint && (unsigned)value > (unsigned)INT_MAX + 1) {
      /* Tries to catch unintentionally providing a negative value.
       * Note that -2147483648 is parsed as -(2147483648), so we don't
       * want to warn for INT_MAX.
       */
      _mesa_glsl_warning(lloc, state,
			 "signed literal value `%s' is interpreted as %d",
			 text, lval->n);
   }
   if (is_long)
      return is_uint ? UINT64CONSTANT : INT64CONSTANT;
   else
      return is_uint ? UINTCONSTANT : INTCONSTANT;
}

#define LITERAL_INTEGER(base) \
   literal_integer(yytext, yyleng, yyextra, yylval, yylloc, base)

#line 1653 "src/compiler/glsl/glsl_lexer.cpp"
#line 221 "../src/compiler/glsl/glsl_lexer.ll"
	/* Note: When adding any start conditions to this list, you must also
	 * update the "Internal compiler error" catch-all rule near the end of
	 * this file. */

#line 1659 "src/compiler/glsl/glsl_lexer.cpp"

#define INITIAL 0
#define PP 1
#define PRAGMA 2

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#define YY_EXTRA_TYPE struct _mesa_glsl_parse_state *

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    int yy_n_chars;
    int yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    YYSTYPE * yylval_r;

    YYLTYPE * yylloc_r;

    }; /* end struct yyguts_t */

static int yy_init_globals ( yyscan_t yyscanner );

    /* This must go here because YYSTYPE and YYLTYPE are included
     * from bison output in section 1.*/
    #    define yylval yyg->yylval_r
    
    #    define yylloc yyg->yylloc_r
    
int yylex_init (yyscan_t* scanner);

int yylex_init_extra ( YY_EXTRA_TYPE user_defined, yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( yyscan_t yyscanner );

int yyget_debug ( yyscan_t yyscanner );

void yyset_debug ( int debug_flag , yyscan_t yyscanner );

YY_EXTRA_TYPE yyget_extra ( yyscan_t yyscanner );

void yyset_extra ( YY_EXTRA_TYPE user_defined , yyscan_t yyscanner );

FILE *yyget_in ( yyscan_t yyscanner );

void yyset_in  ( FILE * _in_str , yyscan_t yyscanner );

FILE *yyget_out ( yyscan_t yyscanner );

void yyset_out  ( FILE * _out_str , yyscan_t yyscanner );

			int yyget_leng ( yyscan_t yyscanner );

char *yyget_text ( yyscan_t yyscanner );

int yyget_lineno ( yyscan_t yyscanner );

void yyset_lineno ( int _line_number , yyscan_t yyscanner );

int yyget_column  ( yyscan_t yyscanner );

void yyset_column ( int _column_no , yyscan_t yyscanner );

YYSTYPE * yyget_lval ( yyscan_t yyscanner );

void yyset_lval ( YYSTYPE * yylval_param , yyscan_t yyscanner );

       YYLTYPE *yyget_lloc ( yyscan_t yyscanner );
    
        void yyset_lloc ( YYLTYPE * yylloc_param , yyscan_t yyscanner );
    
/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( yyscan_t yyscanner );
#else
extern int yywrap ( yyscan_t yyscanner );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int , yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * , yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( yyscan_t yyscanner );
#else
static int input ( yyscan_t yyscanner );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex \
               (YYSTYPE * yylval_param, YYLTYPE * yylloc_param , yyscan_t yyscanner);

#define YY_DECL int yylex \
               (YYSTYPE * yylval_param, YYLTYPE * yylloc_param , yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	if ( yyleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(yytext[yyleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    yylval = yylval_param;

    yylloc = yylloc_param;

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
		}

		yy_load_buffer_state( yyscanner );
		}

	{
#line 234 "../src/compiler/glsl/glsl_lexer.ll"


#line 1947 "src/compiler/glsl/glsl_lexer.cpp"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yyg->yy_start;
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				yyg->yy_last_accepting_state = yy_current_state;
				yyg->yy_last_accepting_cpos = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 1187 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 1186 );
		yy_cp = yyg->yy_last_accepting_cpos;
		yy_current_state = yyg->yy_last_accepting_state;

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = yyg->yy_hold_char;
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 236 "../src/compiler/glsl/glsl_lexer.ll"
;
	YY_BREAK
/* Preprocessor tokens. */
case 2:
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 239 "../src/compiler/glsl/glsl_lexer.ll"
;
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 240 "../src/compiler/glsl/glsl_lexer.ll"
{ BEGIN PP; return VERSION_TOK; }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 241 "../src/compiler/glsl/glsl_lexer.ll"
{ BEGIN PP; return EXTENSION; }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 242 "../src/compiler/glsl/glsl_lexer.ll"
{
                                  if (!yyextra->ARB_shading_language_include_enable) {
                                     struct _mesa_glsl_parse_state *state = yyextra;
                                     _mesa_glsl_error(yylloc, state,
                                                      "ARB_shading_language_include required "
                                                      "to use #include");
                                   }
}
	YY_BREAK
case 6:
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 250 "../src/compiler/glsl/glsl_lexer.ll"
{
				   /* Eat characters until the first digit is
				    * encountered
				    */
				   char *ptr = yytext;
				   while (!isdigit(*ptr))
				      ptr++;

				   /* Subtract one from the line number because
				    * yylineno is zero-based instead of
				    * one-based.
				    */
				   yylineno = strtol(ptr, &ptr, 0) - 1;

                                   /* From GLSL 3.30 and GLSL ES on, after processing the
                                    * line directive (including its new-line), the implementation
                                    * will behave as if it is compiling at the line number passed
                                    * as argument. It was line number + 1 in older specifications.
                                    */
                                   if (yyextra->is_version(330, 100))
                                      yylineno--;

				   yylloc->source = strtol(ptr, NULL, 0);
                                   yylloc->path = NULL;
				}
	YY_BREAK
case 7:
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 275 "../src/compiler/glsl/glsl_lexer.ll"
{
                                   if (!yyextra->ARB_shading_language_include_enable) {
                                      struct _mesa_glsl_parse_state *state = yyextra;
                                      _mesa_glsl_error(yylloc, state,
                                                       "ARB_shading_language_include required "
                                                       "to use #line <line> \"<path>\"");
                                   }

                                   /* Eat characters until the first digit is
                                    * encountered
                                    */
                                   char *ptr = yytext;
                                   while (!isdigit(*ptr))
                                      ptr++;

                                   /* Subtract one from the line number because
                                    * yylineno is zero-based instead of
                                    * one-based.
                                    */
                                   yylineno = strtol(ptr, &ptr, 0) - 1;

                                   /* From GLSL 3.30 and GLSL ES on, after processing the
                                    * line directive (including its new-line), the implementation
                                    * will behave as if it is compiling at the line number passed
                                    * as argument. It was line number + 1 in older specifications.
                                    */
                                   if (yyextra->is_version(330, 100))
                                      yylineno--;

                                   while (isspace(*ptr))
                                      ptr++;

                                   /* Skip over leading " */
                                   ptr++;

                                   char *end = strrchr(ptr, '"');
                                   int path_len = (end - ptr) + 1;
                                   linear_ctx *mem_ctx = yyextra->linalloc;
                                   yylloc->path = (char *) linear_alloc_child(mem_ctx, path_len);
                                   memcpy(yylloc->path, ptr, path_len);
                                   yylloc->path[path_len - 1] = '\0';
                                }
	YY_BREAK
case 8:
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */
yyg->yy_c_buf_p = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 317 "../src/compiler/glsl/glsl_lexer.ll"
{
				   /* Eat characters until the first digit is
				    * encountered
				    */
				   char *ptr = yytext;
				   while (!isdigit(*ptr))
				      ptr++;

				   /* Subtract one from the line number because
				    * yylineno is zero-based instead of
				    * one-based.
				    */
				   yylineno = strtol(ptr, &ptr, 0) - 1;

                                   /* From GLSL 3.30 and GLSL ES on, after processing the
                                    * line directive (including its new-line), the implementation
                                    * will behave as if it is compiling at the line number passed
                                    * as argument. It was line number + 1 in older specifications.
                                    */
                                   if (yyextra->is_version(330, 100))
                                      yylineno--;
				}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 339 "../src/compiler/glsl/glsl_lexer.ll"
{
				  BEGIN PP;
				  return PRAGMA_DEBUG_ON;
				}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 343 "../src/compiler/glsl/glsl_lexer.ll"
{
				  BEGIN PP;
				  return PRAGMA_DEBUG_OFF;
				}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 347 "../src/compiler/glsl/glsl_lexer.ll"
{
				  BEGIN PP;
				  return PRAGMA_OPTIMIZE_ON;
				}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 351 "../src/compiler/glsl/glsl_lexer.ll"
{
				  BEGIN PP;
				  return PRAGMA_OPTIMIZE_OFF;
				}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 355 "../src/compiler/glsl/glsl_lexer.ll"
{
				  BEGIN PP;
				  return PRAGMA_WARNING_ON;
				}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 359 "../src/compiler/glsl/glsl_lexer.ll"
{
				  BEGIN PP;
				  return PRAGMA_WARNING_OFF;
				}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 363 "../src/compiler/glsl/glsl_lexer.ll"
{
				  BEGIN PP;
				  return PRAGMA_INVARIANT_ALL;
				}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 367 "../src/compiler/glsl/glsl_lexer.ll"
{ BEGIN PRAGMA; }
	YY_BREAK
case 17:
/* rule 17 can match eol */
YY_RULE_SETUP
#line 369 "../src/compiler/glsl/glsl_lexer.ll"
{ BEGIN 0; yylineno++; yycolumn = 0; }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 370 "../src/compiler/glsl/glsl_lexer.ll"
{ }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 372 "../src/compiler/glsl/glsl_lexer.ll"
{ }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 373 "../src/compiler/glsl/glsl_lexer.ll"
{ }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 374 "../src/compiler/glsl/glsl_lexer.ll"
return COLON;
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 375 "../src/compiler/glsl/glsl_lexer.ll"
{
				   /* We're not doing linear_strdup here, to avoid an implicit call
				    * on strlen() for the length of the string, as this is already
				    * found by flex and stored in yyleng
				    */
                                    linear_ctx *mem_ctx = yyextra->linalloc;
                                    char *id = (char *) linear_alloc_child(mem_ctx, yyleng + 1);
                                    memcpy(id, yytext, yyleng + 1);
                                    yylval->identifier = id;
				   return IDENTIFIER;
				}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 386 "../src/compiler/glsl/glsl_lexer.ll"
{
				    yylval->n = strtol(yytext, NULL, 10);
				    return INTCONSTANT;
				}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 390 "../src/compiler/glsl/glsl_lexer.ll"
{
				    yylval->n = 0;
				    return INTCONSTANT;
				}
	YY_BREAK
case 25:
/* rule 25 can match eol */
YY_RULE_SETUP
#line 394 "../src/compiler/glsl/glsl_lexer.ll"
{ BEGIN 0; yylineno++; yycolumn = 0; return EOL; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 395 "../src/compiler/glsl/glsl_lexer.ll"
{ return yytext[0]; }
	YY_BREAK
case 27:
/* rule 27 can match eol */
YY_RULE_SETUP
#line 397 "../src/compiler/glsl/glsl_lexer.ll"
{ yylineno++; yycolumn = 0; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 399 "../src/compiler/glsl/glsl_lexer.ll"
DEPRECATED_KEYWORD(ATTRIBUTE, yyextra, 420, 300);
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 400 "../src/compiler/glsl/glsl_lexer.ll"
return CONST_TOK;
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 401 "../src/compiler/glsl/glsl_lexer.ll"
{ yylval->type = &glsl_type_builtin_bool; return BASIC_TYPE_TOK; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 402 "../src/compiler/glsl/glsl_lexer.ll"
{ yylval->type = &glsl_type_builtin_float; return BASIC_TYPE_TOK; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 403 "../src/compiler/glsl/glsl_lexer.ll"
{ yylval->type = &glsl_type_builtin_int; return BASIC_TYPE_TOK; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 404 "../src/compiler/glsl/glsl_lexer.ll"
TYPE(130, 300, 130, 300, &glsl_type_builtin_uint);
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 406 "../src/compiler/glsl/glsl_lexer.ll"
return BREAK;
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 407 "../src/compiler/glsl/glsl_lexer.ll"
return CONTINUE;
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 408 "../src/compiler/glsl/glsl_lexer.ll"
return DO;
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 409 "../src/compiler/glsl/glsl_lexer.ll"
return WHILE;
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 410 "../src/compiler/glsl/glsl_lexer.ll"
return ELSE;
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 411 "../src/compiler/glsl/glsl_lexer.ll"
return FOR;
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 412 "../src/compiler/glsl/glsl_lexer.ll"
return IF;
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 413 "../src/compiler/glsl/glsl_lexer.ll"
return DISCARD;
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 414 "../src/compiler/glsl/glsl_lexer.ll"
return RETURN;
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 415 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(0, 0, 0, 0, yyextra->EXT_demote_to_helper_invocation_enable, DEMOTE);
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 417 "../src/compiler/glsl/glsl_lexer.ll"
{ yylval->type = &glsl_type_builtin_bvec2; return BASIC_TYPE_TOK; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 418 "../src/compiler/glsl/glsl_lexer.ll"
{ yylval->type = &glsl_type_builtin_bvec3; return BASIC_TYPE_TOK; }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 419 "../src/compiler/glsl/glsl_lexer.ll"
{ yylval->type = &glsl_type_builtin_bvec4; return BASIC_TYPE_TOK; }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 420 "../src/compiler/glsl/glsl_lexer.ll"
{ yylval->type = &glsl_type_builtin_ivec2; return BASIC_TYPE_TOK; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 421 "../src/compiler/glsl/glsl_lexer.ll"
{ yylval->type = &glsl_type_builtin_ivec3; return BASIC_TYPE_TOK; }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 422 "../src/compiler/glsl/glsl_lexer.ll"
{ yylval->type = &glsl_type_builtin_ivec4; return BASIC_TYPE_TOK; }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 423 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 130, 300, yyextra->EXT_gpu_shader4_enable, &glsl_type_builtin_uvec2);
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 424 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 130, 300, yyextra->EXT_gpu_shader4_enable, &glsl_type_builtin_uvec3);
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 425 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 130, 300, yyextra->EXT_gpu_shader4_enable, &glsl_type_builtin_uvec4);
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 426 "../src/compiler/glsl/glsl_lexer.ll"
{ yylval->type = &glsl_type_builtin_vec2; return BASIC_TYPE_TOK; }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 427 "../src/compiler/glsl/glsl_lexer.ll"
{ yylval->type = &glsl_type_builtin_vec3; return BASIC_TYPE_TOK; }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 428 "../src/compiler/glsl/glsl_lexer.ll"
{ yylval->type = &glsl_type_builtin_vec4; return BASIC_TYPE_TOK; }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 429 "../src/compiler/glsl/glsl_lexer.ll"
{ yylval->type = &glsl_type_builtin_mat2; return BASIC_TYPE_TOK; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 430 "../src/compiler/glsl/glsl_lexer.ll"
{ yylval->type = &glsl_type_builtin_mat3; return BASIC_TYPE_TOK; }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 431 "../src/compiler/glsl/glsl_lexer.ll"
{ yylval->type = &glsl_type_builtin_mat4; return BASIC_TYPE_TOK; }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 432 "../src/compiler/glsl/glsl_lexer.ll"
TYPE(120, 300, 120, 300, &glsl_type_builtin_mat2);
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 433 "../src/compiler/glsl/glsl_lexer.ll"
TYPE(120, 300, 120, 300, &glsl_type_builtin_mat2x3);
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 434 "../src/compiler/glsl/glsl_lexer.ll"
TYPE(120, 300, 120, 300, &glsl_type_builtin_mat2x4);
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 435 "../src/compiler/glsl/glsl_lexer.ll"
TYPE(120, 300, 120, 300, &glsl_type_builtin_mat3x2);
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 436 "../src/compiler/glsl/glsl_lexer.ll"
TYPE(120, 300, 120, 300, &glsl_type_builtin_mat3);
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 437 "../src/compiler/glsl/glsl_lexer.ll"
TYPE(120, 300, 120, 300, &glsl_type_builtin_mat3x4);
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 438 "../src/compiler/glsl/glsl_lexer.ll"
TYPE(120, 300, 120, 300, &glsl_type_builtin_mat4x2);
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 439 "../src/compiler/glsl/glsl_lexer.ll"
TYPE(120, 300, 120, 300, &glsl_type_builtin_mat4x3);
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 440 "../src/compiler/glsl/glsl_lexer.ll"
TYPE(120, 300, 120, 300, &glsl_type_builtin_mat4);
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 442 "../src/compiler/glsl/glsl_lexer.ll"
return IN_TOK;
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 443 "../src/compiler/glsl/glsl_lexer.ll"
return OUT_TOK;
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 444 "../src/compiler/glsl/glsl_lexer.ll"
return INOUT_TOK;
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 445 "../src/compiler/glsl/glsl_lexer.ll"
return UNIFORM;
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 446 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(0, 0, 430, 310, yyextra->ARB_shader_storage_buffer_object_enable, BUFFER);
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 447 "../src/compiler/glsl/glsl_lexer.ll"
DEPRECATED_KEYWORD(VARYING, yyextra, 420, 300);
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 448 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(120, 300, 120, 300, yyextra->EXT_gpu_shader4_enable, CENTROID);
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 449 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(120, 100, 120, 100, INVARIANT);
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 450 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(130, 100, 130, 300, yyextra->EXT_gpu_shader4_enable, FLAT);
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 451 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(130, 300, 130, 300, SMOOTH);
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 452 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(130, 300, 130, 0, yyextra->EXT_gpu_shader4_enable || yyextra->NV_shader_noperspective_interpolation_enable, NOPERSPECTIVE);
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 453 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(0, 300, 400, 320, yyextra->has_tessellation_shader(), PATCH);
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 455 "../src/compiler/glsl/glsl_lexer.ll"
DEPRECATED_ES_TYPE(&glsl_type_builtin_sampler1D);
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 456 "../src/compiler/glsl/glsl_lexer.ll"
{ yylval->type = &glsl_type_builtin_sampler2D; return BASIC_TYPE_TOK; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 457 "../src/compiler/glsl/glsl_lexer.ll"
{ yylval->type = &glsl_type_builtin_sampler3D; return BASIC_TYPE_TOK; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 458 "../src/compiler/glsl/glsl_lexer.ll"
{ yylval->type = &glsl_type_builtin_samplerCube; return BASIC_TYPE_TOK; }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 459 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 130, 0,   yyextra->EXT_gpu_shader4_enable && yyextra->exts->EXT_texture_array, &glsl_type_builtin_sampler1DArray);
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 460 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 130, 300, yyextra->EXT_gpu_shader4_enable && yyextra->exts->EXT_texture_array, &glsl_type_builtin_sampler2DArray);
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 461 "../src/compiler/glsl/glsl_lexer.ll"
DEPRECATED_ES_TYPE(&glsl_type_builtin_sampler1DShadow);
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 462 "../src/compiler/glsl/glsl_lexer.ll"
{ yylval->type = &glsl_type_builtin_sampler2DShadow; return BASIC_TYPE_TOK; }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 463 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 130, 300, yyextra->EXT_gpu_shader4_enable, &glsl_type_builtin_samplerCubeShadow);
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 464 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 130, 0,   yyextra->EXT_gpu_shader4_enable && yyextra->exts->EXT_texture_array, &glsl_type_builtin_sampler1DArrayShadow);
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 465 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 130, 300, yyextra->EXT_gpu_shader4_enable && yyextra->exts->EXT_texture_array, &glsl_type_builtin_sampler2DArrayShadow);
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 466 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 130, 0,   yyextra->EXT_gpu_shader4_enable && yyextra->exts->EXT_texture_integer, &glsl_type_builtin_isampler1D);
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 467 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 130, 300, yyextra->EXT_gpu_shader4_enable && yyextra->exts->EXT_texture_integer, &glsl_type_builtin_isampler2D);
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 468 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 130, 300, yyextra->EXT_gpu_shader4_enable && yyextra->exts->EXT_texture_integer, &glsl_type_builtin_isampler3D);
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 469 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 130, 300, yyextra->EXT_gpu_shader4_enable && yyextra->exts->EXT_texture_integer, &glsl_type_builtin_isamplerCube);
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 470 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 130, 0,   yyextra->EXT_gpu_shader4_enable && yyextra->exts->EXT_texture_integer && yyextra->exts->EXT_texture_array, &glsl_type_builtin_isampler1DArray);
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 471 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 130, 300, yyextra->EXT_gpu_shader4_enable && yyextra->exts->EXT_texture_integer && yyextra->exts->EXT_texture_array, &glsl_type_builtin_isampler2DArray);
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 472 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 130, 0,   yyextra->EXT_gpu_shader4_enable && yyextra->exts->EXT_texture_integer, &glsl_type_builtin_usampler1D);
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 473 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 130, 300, yyextra->EXT_gpu_shader4_enable && yyextra->exts->EXT_texture_integer, &glsl_type_builtin_usampler2D);
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 474 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 130, 300, yyextra->EXT_gpu_shader4_enable && yyextra->exts->EXT_texture_integer, &glsl_type_builtin_usampler3D);
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 475 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 130, 300, yyextra->EXT_gpu_shader4_enable && yyextra->exts->EXT_texture_integer, &glsl_type_builtin_usamplerCube);
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 476 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 130, 0,   yyextra->EXT_gpu_shader4_enable && yyextra->exts->EXT_texture_integer && yyextra->exts->EXT_texture_array, &glsl_type_builtin_usampler1DArray);
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 477 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 130, 300, yyextra->EXT_gpu_shader4_enable && yyextra->exts->EXT_texture_integer && yyextra->exts->EXT_texture_array, &glsl_type_builtin_usampler2DArray);
	YY_BREAK
/* additional keywords in ARB_texture_multisample, included in GLSL 1.50 */
/* these are reserved but not defined in GLSL 3.00 */
/* [iu]sampler2DMS are defined in GLSL ES 3.10 */
case 103:
YY_RULE_SETUP
#line 482 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(150, 300, 150, 310, yyextra->ARB_texture_multisample_enable, &glsl_type_builtin_sampler2DMS);
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 483 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(150, 300, 150, 310, yyextra->ARB_texture_multisample_enable, &glsl_type_builtin_isampler2DMS);
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 484 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(150, 300, 150, 310, yyextra->ARB_texture_multisample_enable, &glsl_type_builtin_usampler2DMS);
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 485 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(150, 300, 150, 320, yyextra->ARB_texture_multisample_enable || yyextra->OES_texture_storage_multisample_2d_array_enable, &glsl_type_builtin_sampler2DMSArray);
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 486 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(150, 300, 150, 320, yyextra->ARB_texture_multisample_enable || yyextra->OES_texture_storage_multisample_2d_array_enable, &glsl_type_builtin_isampler2DMSArray);
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 487 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(150, 300, 150, 320, yyextra->ARB_texture_multisample_enable || yyextra->OES_texture_storage_multisample_2d_array_enable, &glsl_type_builtin_usampler2DMSArray);
	YY_BREAK
/* keywords available with ARB_texture_cube_map_array_enable extension on desktop GLSL */
case 109:
YY_RULE_SETUP
#line 490 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(400, 310, 400, 320, yyextra->ARB_texture_cube_map_array_enable || yyextra->OES_texture_cube_map_array_enable || yyextra->EXT_texture_cube_map_array_enable, &glsl_type_builtin_samplerCubeArray);
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 491 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(400, 310, 400, 320, yyextra->ARB_texture_cube_map_array_enable || yyextra->OES_texture_cube_map_array_enable || yyextra->EXT_texture_cube_map_array_enable, &glsl_type_builtin_isamplerCubeArray);
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 492 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(400, 310, 400, 320, yyextra->ARB_texture_cube_map_array_enable || yyextra->OES_texture_cube_map_array_enable || yyextra->EXT_texture_cube_map_array_enable, &glsl_type_builtin_usamplerCubeArray);
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 493 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(400, 310, 400, 320, yyextra->ARB_texture_cube_map_array_enable || yyextra->OES_texture_cube_map_array_enable || yyextra->EXT_texture_cube_map_array_enable, &glsl_type_builtin_samplerCubeArrayShadow);
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 495 "../src/compiler/glsl/glsl_lexer.ll"
{
			  if (yyextra->OES_EGL_image_external_enable || yyextra->OES_EGL_image_external_essl3_enable) {
			     yylval->type = &glsl_type_builtin_samplerExternalOES;
			     return BASIC_TYPE_TOK;
			  } else
			     return IDENTIFIER;
		}
	YY_BREAK
/* keywords available with ARB_gpu_shader5 */
case 114:
YY_RULE_SETUP
#line 504 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(400, 310, 400, 320, yyextra->ARB_gpu_shader5_enable || yyextra->EXT_gpu_shader5_enable || yyextra->OES_gpu_shader5_enable, PRECISE);
	YY_BREAK
/* keywords available with ARB_shader_image_load_store */
case 115:
YY_RULE_SETUP
#line 507 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 420, 0, yyextra->ARB_shader_image_load_store_enable || yyextra->EXT_shader_image_load_store_enable, &glsl_type_builtin_image1D);
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 508 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 420, 310, yyextra->ARB_shader_image_load_store_enable || yyextra->EXT_shader_image_load_store_enable, &glsl_type_builtin_image2D);
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 509 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 420, 310, yyextra->ARB_shader_image_load_store_enable || yyextra->EXT_shader_image_load_store_enable, &glsl_type_builtin_image3D);
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 510 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 420, 0, yyextra->ARB_shader_image_load_store_enable || yyextra->EXT_shader_image_load_store_enable, &glsl_type_builtin_image2DRect);
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 511 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 420, 310, yyextra->ARB_shader_image_load_store_enable || yyextra->EXT_shader_image_load_store_enable, &glsl_type_builtin_imageCube);
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 512 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 420, 320, yyextra->ARB_shader_image_load_store_enable || yyextra->EXT_shader_image_load_store_enable || yyextra->EXT_texture_buffer_enable || yyextra->OES_texture_buffer_enable, &glsl_type_builtin_imageBuffer);
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 513 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 420, 0, yyextra->ARB_shader_image_load_store_enable || yyextra->EXT_shader_image_load_store_enable, &glsl_type_builtin_image1DArray);
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 514 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 420, 310, yyextra->ARB_shader_image_load_store_enable || yyextra->EXT_shader_image_load_store_enable, &glsl_type_builtin_image2DArray);
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 515 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 420, 320, yyextra->ARB_shader_image_load_store_enable || yyextra->EXT_shader_image_load_store_enable || yyextra->OES_texture_cube_map_array_enable || yyextra->EXT_texture_cube_map_array_enable, &glsl_type_builtin_imageCubeArray);
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 516 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 420, 0, yyextra->ARB_shader_image_load_store_enable || yyextra->EXT_shader_image_load_store_enable, &glsl_type_builtin_image2DMS);
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 517 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 420, 0, yyextra->ARB_shader_image_load_store_enable || yyextra->EXT_shader_image_load_store_enable, &glsl_type_builtin_image2DMSArray);
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 518 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 420, 0, yyextra->ARB_shader_image_load_store_enable || yyextra->EXT_shader_image_load_store_enable, &glsl_type_builtin_iimage1D);
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 519 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 420, 310, yyextra->ARB_shader_image_load_store_enable || yyextra->EXT_shader_image_load_store_enable, &glsl_type_builtin_iimage2D);
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 520 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 420, 310, yyextra->ARB_shader_image_load_store_enable || yyextra->EXT_shader_image_load_store_enable, &glsl_type_builtin_iimage3D);
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 521 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 420, 0, yyextra->ARB_shader_image_load_store_enable || yyextra->EXT_shader_image_load_store_enable, &glsl_type_builtin_iimage2DRect);
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 522 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 420, 310, yyextra->ARB_shader_image_load_store_enable || yyextra->EXT_shader_image_load_store_enable, &glsl_type_builtin_iimageCube);
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 523 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 420, 320, yyextra->ARB_shader_image_load_store_enable || yyextra->EXT_shader_image_load_store_enable || yyextra->EXT_texture_buffer_enable || yyextra->OES_texture_buffer_enable, &glsl_type_builtin_iimageBuffer);
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 524 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 420, 0, yyextra->ARB_shader_image_load_store_enable || yyextra->EXT_shader_image_load_store_enable, &glsl_type_builtin_iimage1DArray);
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 525 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 420, 310, yyextra->ARB_shader_image_load_store_enable || yyextra->EXT_shader_image_load_store_enable, &glsl_type_builtin_iimage2DArray);
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 526 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 420, 320, yyextra->ARB_shader_image_load_store_enable || yyextra->EXT_shader_image_load_store_enable || yyextra->OES_texture_cube_map_array_enable || yyextra->EXT_texture_cube_map_array_enable, &glsl_type_builtin_iimageCubeArray);
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 527 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 420, 0, yyextra->ARB_shader_image_load_store_enable || yyextra->EXT_shader_image_load_store_enable, &glsl_type_builtin_iimage2DMS);
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 528 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 420, 0, yyextra->ARB_shader_image_load_store_enable || yyextra->EXT_shader_image_load_store_enable, &glsl_type_builtin_iimage2DMSArray);
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 529 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 420, 0, yyextra->ARB_shader_image_load_store_enable || yyextra->EXT_shader_image_load_store_enable, &glsl_type_builtin_uimage1D);
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 530 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 420, 310, yyextra->ARB_shader_image_load_store_enable || yyextra->EXT_shader_image_load_store_enable, &glsl_type_builtin_uimage2D);
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 531 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 420, 310, yyextra->ARB_shader_image_load_store_enable || yyextra->EXT_shader_image_load_store_enable, &glsl_type_builtin_uimage3D);
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 532 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 420, 0, yyextra->ARB_shader_image_load_store_enable || yyextra->EXT_shader_image_load_store_enable, &glsl_type_builtin_uimage2DRect);
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 533 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 420, 310, yyextra->ARB_shader_image_load_store_enable || yyextra->EXT_shader_image_load_store_enable, &glsl_type_builtin_uimageCube);
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 534 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 420, 320, yyextra->ARB_shader_image_load_store_enable || yyextra->EXT_shader_image_load_store_enable || yyextra->EXT_texture_buffer_enable || yyextra->OES_texture_buffer_enable, &glsl_type_builtin_uimageBuffer);
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 535 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 420, 0, yyextra->ARB_shader_image_load_store_enable || yyextra->EXT_shader_image_load_store_enable, &glsl_type_builtin_uimage1DArray);
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 536 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 420, 310, yyextra->ARB_shader_image_load_store_enable || yyextra->EXT_shader_image_load_store_enable, &glsl_type_builtin_uimage2DArray);
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 537 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 420, 320, yyextra->ARB_shader_image_load_store_enable || yyextra->EXT_shader_image_load_store_enable || yyextra->OES_texture_cube_map_array_enable || yyextra->EXT_texture_cube_map_array_enable, &glsl_type_builtin_uimageCubeArray);
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 538 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 420, 0, yyextra->ARB_shader_image_load_store_enable || yyextra->EXT_shader_image_load_store_enable, &glsl_type_builtin_uimage2DMS);
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 539 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 420, 0, yyextra->ARB_shader_image_load_store_enable || yyextra->EXT_shader_image_load_store_enable, &glsl_type_builtin_uimage2DMSArray);
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 540 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(130, 0, 420, 0, IMAGE1DSHADOW);
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 541 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(130, 0, 420, 0, IMAGE2DSHADOW);
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 542 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(130, 0, 420, 0, IMAGE1DARRAYSHADOW);
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 543 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(130, 0, 420, 0, IMAGE2DARRAYSHADOW);
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 545 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(420, 300, 420, 310, yyextra->ARB_shader_image_load_store_enable || yyextra->EXT_shader_image_load_store_enable || yyextra->ARB_shader_storage_buffer_object_enable, COHERENT);
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 546 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(110, 100, 420, 310, yyextra->ARB_shader_image_load_store_enable || yyextra->EXT_shader_image_load_store_enable || yyextra->ARB_shader_storage_buffer_object_enable, VOLATILE);
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 547 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(420, 300, 420, 310, yyextra->ARB_shader_image_load_store_enable || yyextra->EXT_shader_image_load_store_enable || yyextra->ARB_shader_storage_buffer_object_enable, RESTRICT);
	YY_BREAK
case 155:
YY_RULE_SETUP
#line 548 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(420, 300, 420, 310, yyextra->ARB_shader_image_load_store_enable || yyextra->ARB_shader_storage_buffer_object_enable, READONLY);
	YY_BREAK
case 156:
YY_RULE_SETUP
#line 549 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(420, 300, 420, 310, yyextra->ARB_shader_image_load_store_enable || yyextra->ARB_shader_storage_buffer_object_enable, WRITEONLY);
	YY_BREAK
case 157:
YY_RULE_SETUP
#line 551 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(420, 300, 420, 310, yyextra->ARB_shader_atomic_counters_enable, &glsl_type_builtin_atomic_uint);
	YY_BREAK
case 158:
YY_RULE_SETUP
#line 553 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(430, 310, 430, 310, yyextra->ARB_compute_shader_enable, SHARED);
	YY_BREAK
case 159:
YY_RULE_SETUP
#line 555 "../src/compiler/glsl/glsl_lexer.ll"
{
		    if (yyextra->EXT_mesh_shader_enable)
		         return TASKPAYLOAD;
		    else
		         return classify_identifier(yyextra, yytext, yyleng, yylval);
		}
	YY_BREAK
case 160:
YY_RULE_SETUP
#line 562 "../src/compiler/glsl/glsl_lexer.ll"
{
		    if (yyextra->EXT_mesh_shader_enable)
		         return PERPRIMITIVE;
		    else
		         return classify_identifier(yyextra, yytext, yyleng, yylval);
		}
	YY_BREAK
case 161:
YY_RULE_SETUP
#line 569 "../src/compiler/glsl/glsl_lexer.ll"
return STRUCT;
	YY_BREAK
case 162:
YY_RULE_SETUP
#line 570 "../src/compiler/glsl/glsl_lexer.ll"
return VOID_TOK;
	YY_BREAK
case 163:
YY_RULE_SETUP
#line 572 "../src/compiler/glsl/glsl_lexer.ll"
{
		  if ((yyextra->is_version(140, 300))
		      || yyextra->ARB_bindless_texture_enable
		      || yyextra->KHR_blend_equation_advanced_enable
		      || yyextra->AMD_conservative_depth_enable
		      || yyextra->ARB_conservative_depth_enable
		      || yyextra->EXT_conservative_depth_enable
		      || yyextra->ARB_explicit_attrib_location_enable
		      || yyextra->ARB_explicit_uniform_location_enable
                      || yyextra->ARB_post_depth_coverage_enable
                      || yyextra->has_separate_shader_objects()
		      || yyextra->ARB_uniform_buffer_object_enable
		      || yyextra->ARB_fragment_coord_conventions_enable
                      || yyextra->ARB_shading_language_420pack_enable
                      || yyextra->ARB_compute_shader_enable
                      || yyextra->ARB_tessellation_shader_enable
                      || yyextra->EXT_shader_framebuffer_fetch_non_coherent_enable
                      || yyextra->OVR_multiview_enable) {
		      return LAYOUT_TOK;
		   } else {
		      return classify_identifier(yyextra, yytext, yyleng, yylval);
		   }
		}
	YY_BREAK
case 164:
YY_RULE_SETUP
#line 596 "../src/compiler/glsl/glsl_lexer.ll"
return INC_OP;
	YY_BREAK
case 165:
YY_RULE_SETUP
#line 597 "../src/compiler/glsl/glsl_lexer.ll"
return DEC_OP;
	YY_BREAK
case 166:
YY_RULE_SETUP
#line 598 "../src/compiler/glsl/glsl_lexer.ll"
return LE_OP;
	YY_BREAK
case 167:
YY_RULE_SETUP
#line 599 "../src/compiler/glsl/glsl_lexer.ll"
return GE_OP;
	YY_BREAK
case 168:
YY_RULE_SETUP
#line 600 "../src/compiler/glsl/glsl_lexer.ll"
return EQ_OP;
	YY_BREAK
case 169:
YY_RULE_SETUP
#line 601 "../src/compiler/glsl/glsl_lexer.ll"
return NE_OP;
	YY_BREAK
case 170:
YY_RULE_SETUP
#line 602 "../src/compiler/glsl/glsl_lexer.ll"
return AND_OP;
	YY_BREAK
case 171:
YY_RULE_SETUP
#line 603 "../src/compiler/glsl/glsl_lexer.ll"
return OR_OP;
	YY_BREAK
case 172:
YY_RULE_SETUP
#line 604 "../src/compiler/glsl/glsl_lexer.ll"
return XOR_OP;
	YY_BREAK
case 173:
YY_RULE_SETUP
#line 605 "../src/compiler/glsl/glsl_lexer.ll"
return LEFT_OP;
	YY_BREAK
case 174:
YY_RULE_SETUP
#line 606 "../src/compiler/glsl/glsl_lexer.ll"
return RIGHT_OP;
	YY_BREAK
case 175:
YY_RULE_SETUP
#line 608 "../src/compiler/glsl/glsl_lexer.ll"
return MUL_ASSIGN;
	YY_BREAK
case 176:
YY_RULE_SETUP
#line 609 "../src/compiler/glsl/glsl_lexer.ll"
return DIV_ASSIGN;
	YY_BREAK
case 177:
YY_RULE_SETUP
#line 610 "../src/compiler/glsl/glsl_lexer.ll"
return ADD_ASSIGN;
	YY_BREAK
case 178:
YY_RULE_SETUP
#line 611 "../src/compiler/glsl/glsl_lexer.ll"
return MOD_ASSIGN;
	YY_BREAK
case 179:
YY_RULE_SETUP
#line 612 "../src/compiler/glsl/glsl_lexer.ll"
return LEFT_ASSIGN;
	YY_BREAK
case 180:
YY_RULE_SETUP
#line 613 "../src/compiler/glsl/glsl_lexer.ll"
return RIGHT_ASSIGN;
	YY_BREAK
case 181:
YY_RULE_SETUP
#line 614 "../src/compiler/glsl/glsl_lexer.ll"
return AND_ASSIGN;
	YY_BREAK
case 182:
YY_RULE_SETUP
#line 615 "../src/compiler/glsl/glsl_lexer.ll"
return XOR_ASSIGN;
	YY_BREAK
case 183:
YY_RULE_SETUP
#line 616 "../src/compiler/glsl/glsl_lexer.ll"
return OR_ASSIGN;
	YY_BREAK
case 184:
YY_RULE_SETUP
#line 617 "../src/compiler/glsl/glsl_lexer.ll"
return SUB_ASSIGN;
	YY_BREAK
case 185:
YY_RULE_SETUP
#line 619 "../src/compiler/glsl/glsl_lexer.ll"
{
			    return LITERAL_INTEGER(10);
			}
	YY_BREAK
case 186:
YY_RULE_SETUP
#line 622 "../src/compiler/glsl/glsl_lexer.ll"
{
			    return LITERAL_INTEGER(16);
			}
	YY_BREAK
case 187:
YY_RULE_SETUP
#line 625 "../src/compiler/glsl/glsl_lexer.ll"
{
			    return LITERAL_INTEGER(8);
			}
	YY_BREAK
case 188:
#line 630 "../src/compiler/glsl/glsl_lexer.ll"
case 189:
#line 631 "../src/compiler/glsl/glsl_lexer.ll"
case 190:
#line 632 "../src/compiler/glsl/glsl_lexer.ll"
case 191:
YY_RULE_SETUP
#line 632 "../src/compiler/glsl/glsl_lexer.ll"
{
			    if (!yyextra->AMD_gpu_shader_half_float_enable)
			        return ERROR_TOK;
			    yylval->dreal = _mesa_strtod(yytext, NULL);
			    return FLOAT16CONSTANT;
			}
	YY_BREAK
case 192:
#line 640 "../src/compiler/glsl/glsl_lexer.ll"
case 193:
#line 641 "../src/compiler/glsl/glsl_lexer.ll"
case 194:
#line 642 "../src/compiler/glsl/glsl_lexer.ll"
case 195:
YY_RULE_SETUP
#line 642 "../src/compiler/glsl/glsl_lexer.ll"
{
			    struct _mesa_glsl_parse_state *state = yyextra;
			    char suffix = yytext[strlen(yytext) - 1];
			    if (!state->is_version(120, 300) &&
			        (suffix == 'f' || suffix == 'F')) {
			        _mesa_glsl_warning(yylloc, state,
			                           "Float suffixes are invalid in GLSL 1.10");
			    }
			    yylval->real = _mesa_strtof(yytext, NULL);
			    return FLOATCONSTANT;
			}
	YY_BREAK
case 196:
#line 655 "../src/compiler/glsl/glsl_lexer.ll"
case 197:
#line 656 "../src/compiler/glsl/glsl_lexer.ll"
case 198:
#line 657 "../src/compiler/glsl/glsl_lexer.ll"
case 199:
YY_RULE_SETUP
#line 657 "../src/compiler/glsl/glsl_lexer.ll"
{
			    if (!yyextra->is_version(400, 0) &&
			        !yyextra->ARB_gpu_shader_fp64_enable)
			        return ERROR_TOK;
			    yylval->dreal = _mesa_strtod(yytext, NULL);
			    return DOUBLECONSTANT;
			}
	YY_BREAK
case 200:
YY_RULE_SETUP
#line 665 "../src/compiler/glsl/glsl_lexer.ll"
{
			    yylval->n = 1;
			    return BOOLCONSTANT;
			}
	YY_BREAK
case 201:
YY_RULE_SETUP
#line 669 "../src/compiler/glsl/glsl_lexer.ll"
{
			    yylval->n = 0;
			    return BOOLCONSTANT;
			}
	YY_BREAK
/* Reserved words in GLSL 1.10. */
case 202:
YY_RULE_SETUP
#line 676 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, ASM);
	YY_BREAK
case 203:
YY_RULE_SETUP
#line 677 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, CLASS);
	YY_BREAK
case 204:
YY_RULE_SETUP
#line 678 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, UNION);
	YY_BREAK
case 205:
YY_RULE_SETUP
#line 679 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, ENUM);
	YY_BREAK
case 206:
YY_RULE_SETUP
#line 680 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, TYPEDEF);
	YY_BREAK
case 207:
YY_RULE_SETUP
#line 681 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, TEMPLATE);
	YY_BREAK
case 208:
YY_RULE_SETUP
#line 682 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, THIS);
	YY_BREAK
case 209:
YY_RULE_SETUP
#line 683 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(110, 100, 140, 300, yyextra->ARB_uniform_buffer_object_enable, PACKED_TOK);
	YY_BREAK
case 210:
YY_RULE_SETUP
#line 684 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, GOTO);
	YY_BREAK
case 211:
YY_RULE_SETUP
#line 685 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(110, 100, 130, 300, SWITCH);
	YY_BREAK
case 212:
YY_RULE_SETUP
#line 686 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(110, 100, 130, 300, DEFAULT);
	YY_BREAK
case 213:
YY_RULE_SETUP
#line 687 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, INLINE_TOK);
	YY_BREAK
case 214:
YY_RULE_SETUP
#line 688 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, NOINLINE);
	YY_BREAK
case 215:
YY_RULE_SETUP
#line 689 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, PUBLIC_TOK);
	YY_BREAK
case 216:
YY_RULE_SETUP
#line 690 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, STATIC);
	YY_BREAK
case 217:
YY_RULE_SETUP
#line 691 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, EXTERN);
	YY_BREAK
case 218:
YY_RULE_SETUP
#line 692 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, EXTERNAL);
	YY_BREAK
case 219:
YY_RULE_SETUP
#line 693 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, INTERFACE_TOK);
	YY_BREAK
case 220:
YY_RULE_SETUP
#line 694 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, LONG_TOK);
	YY_BREAK
case 221:
YY_RULE_SETUP
#line 695 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, SHORT_TOK);
	YY_BREAK
case 222:
YY_RULE_SETUP
#line 696 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 100, 130, 300, yyextra->ARB_gpu_shader_fp64_enable, &glsl_type_builtin_double);
	YY_BREAK
case 223:
YY_RULE_SETUP
#line 697 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, HALF);
	YY_BREAK
case 224:
YY_RULE_SETUP
#line 698 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, FIXED_TOK);
	YY_BREAK
case 225:
YY_RULE_SETUP
#line 699 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(110, 100, 0, 0, yyextra->EXT_gpu_shader4_enable, UNSIGNED);
	YY_BREAK
case 226:
YY_RULE_SETUP
#line 700 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, INPUT_TOK);
	YY_BREAK
case 227:
YY_RULE_SETUP
#line 701 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, OUTPUT);
	YY_BREAK
case 228:
YY_RULE_SETUP
#line 702 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, HVEC2);
	YY_BREAK
case 229:
YY_RULE_SETUP
#line 703 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, HVEC3);
	YY_BREAK
case 230:
YY_RULE_SETUP
#line 704 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, HVEC4);
	YY_BREAK
case 231:
YY_RULE_SETUP
#line 705 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(110, 100, 400, 0, yyextra->ARB_gpu_shader_fp64_enable, &glsl_type_builtin_dvec2);
	YY_BREAK
case 232:
YY_RULE_SETUP
#line 706 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(110, 100, 400, 0, yyextra->ARB_gpu_shader_fp64_enable, &glsl_type_builtin_dvec3);
	YY_BREAK
case 233:
YY_RULE_SETUP
#line 707 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(110, 100, 400, 0, yyextra->ARB_gpu_shader_fp64_enable, &glsl_type_builtin_dvec4);
	YY_BREAK
case 234:
YY_RULE_SETUP
#line 708 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(110, 100, 400, 0, yyextra->ARB_gpu_shader_fp64_enable, &glsl_type_builtin_dmat2);
	YY_BREAK
case 235:
YY_RULE_SETUP
#line 709 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(110, 100, 400, 0, yyextra->ARB_gpu_shader_fp64_enable, &glsl_type_builtin_dmat3);
	YY_BREAK
case 236:
YY_RULE_SETUP
#line 710 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(110, 100, 400, 0, yyextra->ARB_gpu_shader_fp64_enable, &glsl_type_builtin_dmat4);
	YY_BREAK
case 237:
YY_RULE_SETUP
#line 711 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(110, 100, 400, 0, yyextra->ARB_gpu_shader_fp64_enable, &glsl_type_builtin_dmat2);
	YY_BREAK
case 238:
YY_RULE_SETUP
#line 712 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(110, 100, 400, 0, yyextra->ARB_gpu_shader_fp64_enable, &glsl_type_builtin_dmat2x3);
	YY_BREAK
case 239:
YY_RULE_SETUP
#line 713 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(110, 100, 400, 0, yyextra->ARB_gpu_shader_fp64_enable, &glsl_type_builtin_dmat2x4);
	YY_BREAK
case 240:
YY_RULE_SETUP
#line 714 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(110, 100, 400, 0, yyextra->ARB_gpu_shader_fp64_enable, &glsl_type_builtin_dmat3x2);
	YY_BREAK
case 241:
YY_RULE_SETUP
#line 715 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(110, 100, 400, 0, yyextra->ARB_gpu_shader_fp64_enable, &glsl_type_builtin_dmat3);
	YY_BREAK
case 242:
YY_RULE_SETUP
#line 716 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(110, 100, 400, 0, yyextra->ARB_gpu_shader_fp64_enable, &glsl_type_builtin_dmat3x4);
	YY_BREAK
case 243:
YY_RULE_SETUP
#line 717 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(110, 100, 400, 0, yyextra->ARB_gpu_shader_fp64_enable, &glsl_type_builtin_dmat4x2);
	YY_BREAK
case 244:
YY_RULE_SETUP
#line 718 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(110, 100, 400, 0, yyextra->ARB_gpu_shader_fp64_enable, &glsl_type_builtin_dmat4x3);
	YY_BREAK
case 245:
YY_RULE_SETUP
#line 719 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(110, 100, 400, 0, yyextra->ARB_gpu_shader_fp64_enable, &glsl_type_builtin_dmat4);
	YY_BREAK
case 246:
YY_RULE_SETUP
#line 720 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, FVEC2);
	YY_BREAK
case 247:
YY_RULE_SETUP
#line 721 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, FVEC3);
	YY_BREAK
case 248:
YY_RULE_SETUP
#line 722 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, FVEC4);
	YY_BREAK
case 249:
YY_RULE_SETUP
#line 723 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(110, 100, 0, 0, yyextra->ARB_texture_rectangle_enable, &glsl_type_builtin_sampler2DRect);
	YY_BREAK
case 250:
YY_RULE_SETUP
#line 724 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, SAMPLER3DRECT);
	YY_BREAK
case 251:
YY_RULE_SETUP
#line 725 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(110, 100, 0, 0, yyextra->ARB_texture_rectangle_enable, &glsl_type_builtin_sampler2DRectShadow);
	YY_BREAK
case 252:
YY_RULE_SETUP
#line 726 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, SIZEOF);
	YY_BREAK
case 253:
YY_RULE_SETUP
#line 727 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, CAST);
	YY_BREAK
case 254:
YY_RULE_SETUP
#line 728 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, NAMESPACE);
	YY_BREAK
case 255:
YY_RULE_SETUP
#line 729 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(110, 100, 0, 0, USING);
	YY_BREAK
/* Additional reserved words in GLSL 1.20. */
case 256:
YY_RULE_SETUP
#line 732 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(120, 100, 130, 100, LOWP);
	YY_BREAK
case 257:
YY_RULE_SETUP
#line 733 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(120, 100, 130, 100, MEDIUMP);
	YY_BREAK
case 258:
YY_RULE_SETUP
#line 734 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(120, 100, 130, 100, HIGHP);
	YY_BREAK
case 259:
YY_RULE_SETUP
#line 735 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(120, 100, 130, 100, PRECISION);
	YY_BREAK
/* Additional reserved words in GLSL 1.30. */
case 260:
YY_RULE_SETUP
#line 738 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(130, 300, 130, 300, CASE);
	YY_BREAK
case 261:
YY_RULE_SETUP
#line 739 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(130, 300, 0, 0, COMMON);
	YY_BREAK
case 262:
YY_RULE_SETUP
#line 740 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(130, 300, 0, 0, PARTITION);
	YY_BREAK
case 263:
YY_RULE_SETUP
#line 741 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(130, 300, 0, 0, ACTIVE);
	YY_BREAK
case 264:
YY_RULE_SETUP
#line 742 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(130, 100, 0, 0, SUPERP);
	YY_BREAK
case 265:
YY_RULE_SETUP
#line 743 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(130, 300, 140, 320, yyextra->EXT_texture_buffer_enable || yyextra->OES_texture_buffer_enable || (yyextra->EXT_gpu_shader4_enable && yyextra->exts->EXT_texture_buffer_object), &glsl_type_builtin_samplerBuffer);
	YY_BREAK
case 266:
YY_RULE_SETUP
#line 744 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(130, 300, 0, 0, FILTER);
	YY_BREAK
case 267:
YY_RULE_SETUP
#line 745 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(130, 0, 140, 0, yyextra->ARB_uniform_buffer_object_enable && !yyextra->es_shader, ROW_MAJOR);
	YY_BREAK
/* Additional reserved words in GLSL 1.40 */
case 268:
YY_RULE_SETUP
#line 748 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(140, 300, 140, 0, yyextra->EXT_gpu_shader4_enable && yyextra->exts->NV_texture_rectangle && yyextra->exts->EXT_texture_integer, &glsl_type_builtin_isampler2DRect);
	YY_BREAK
case 269:
YY_RULE_SETUP
#line 749 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(140, 300, 140, 0, yyextra->EXT_gpu_shader4_enable && yyextra->exts->NV_texture_rectangle && yyextra->exts->EXT_texture_integer, &glsl_type_builtin_usampler2DRect);
	YY_BREAK
case 270:
YY_RULE_SETUP
#line 750 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(140, 300, 140, 320, yyextra->EXT_texture_buffer_enable || yyextra->OES_texture_buffer_enable || (yyextra->EXT_gpu_shader4_enable && yyextra->exts->EXT_texture_buffer_object && yyextra->exts->EXT_texture_integer), &glsl_type_builtin_isamplerBuffer);
	YY_BREAK
case 271:
YY_RULE_SETUP
#line 751 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(140, 300, 140, 320, yyextra->EXT_texture_buffer_enable || yyextra->OES_texture_buffer_enable || (yyextra->EXT_gpu_shader4_enable && yyextra->exts->EXT_texture_buffer_object && yyextra->exts->EXT_texture_integer), &glsl_type_builtin_usamplerBuffer);
	YY_BREAK
/* Additional reserved words in GLSL ES 3.00 */
case 272:
YY_RULE_SETUP
#line 754 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD(420, 300, 0, 0, RESOURCE);
	YY_BREAK
case 273:
YY_RULE_SETUP
#line 755 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(400, 300, 400, 320, yyextra->ARB_gpu_shader5_enable || yyextra->OES_shader_multisample_interpolation_enable, SAMPLE);
	YY_BREAK
case 274:
YY_RULE_SETUP
#line 756 "../src/compiler/glsl/glsl_lexer.ll"
KEYWORD_WITH_ALT(400, 300, 400, 0, yyextra->ARB_shader_subroutine_enable, SUBROUTINE);
	YY_BREAK
/* Additional words for ARB_gpu_shader_int64 */
case 275:
YY_RULE_SETUP
#line 759 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(0, 0, 0, 0, yyextra->ARB_gpu_shader_int64_enable || yyextra->AMD_gpu_shader_int64_enable, &glsl_type_builtin_int64_t);
	YY_BREAK
case 276:
YY_RULE_SETUP
#line 760 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(0, 0, 0, 0, yyextra->ARB_gpu_shader_int64_enable || yyextra->AMD_gpu_shader_int64_enable, &glsl_type_builtin_i64vec2);
	YY_BREAK
case 277:
YY_RULE_SETUP
#line 761 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(0, 0, 0, 0, yyextra->ARB_gpu_shader_int64_enable || yyextra->AMD_gpu_shader_int64_enable, &glsl_type_builtin_i64vec3);
	YY_BREAK
case 278:
YY_RULE_SETUP
#line 762 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(0, 0, 0, 0, yyextra->ARB_gpu_shader_int64_enable || yyextra->AMD_gpu_shader_int64_enable, &glsl_type_builtin_i64vec4);
	YY_BREAK
case 279:
YY_RULE_SETUP
#line 764 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(0, 0, 0, 0, yyextra->ARB_gpu_shader_int64_enable || yyextra->AMD_gpu_shader_int64_enable, &glsl_type_builtin_uint64_t);
	YY_BREAK
case 280:
YY_RULE_SETUP
#line 765 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(0, 0, 0, 0, yyextra->ARB_gpu_shader_int64_enable || yyextra->AMD_gpu_shader_int64_enable, &glsl_type_builtin_u64vec2);
	YY_BREAK
case 281:
YY_RULE_SETUP
#line 766 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(0, 0, 0, 0, yyextra->ARB_gpu_shader_int64_enable || yyextra->AMD_gpu_shader_int64_enable, &glsl_type_builtin_u64vec3);
	YY_BREAK
case 282:
YY_RULE_SETUP
#line 767 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(0, 0, 0, 0, yyextra->ARB_gpu_shader_int64_enable || yyextra->AMD_gpu_shader_int64_enable, &glsl_type_builtin_u64vec4);
	YY_BREAK
/* Additional words for AMD_gpu_shader_half_float */
case 283:
YY_RULE_SETUP
#line 770 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(0, 0, 0, 0, yyextra->AMD_gpu_shader_half_float_enable, &glsl_type_builtin_float16_t);
	YY_BREAK
case 284:
YY_RULE_SETUP
#line 771 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(0, 0, 0, 0, yyextra->AMD_gpu_shader_half_float_enable, &glsl_type_builtin_f16vec2);
	YY_BREAK
case 285:
YY_RULE_SETUP
#line 772 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(0, 0, 0, 0, yyextra->AMD_gpu_shader_half_float_enable, &glsl_type_builtin_f16vec3);
	YY_BREAK
case 286:
YY_RULE_SETUP
#line 773 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(0, 0, 0, 0, yyextra->AMD_gpu_shader_half_float_enable, &glsl_type_builtin_f16vec4);
	YY_BREAK
case 287:
YY_RULE_SETUP
#line 774 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(0, 0, 0, 0, yyextra->AMD_gpu_shader_half_float_enable, &glsl_type_builtin_f16mat2);
	YY_BREAK
case 288:
YY_RULE_SETUP
#line 775 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(0, 0, 0, 0, yyextra->AMD_gpu_shader_half_float_enable, &glsl_type_builtin_f16mat3);
	YY_BREAK
case 289:
YY_RULE_SETUP
#line 776 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(0, 0, 0, 0, yyextra->AMD_gpu_shader_half_float_enable, &glsl_type_builtin_f16mat4);
	YY_BREAK
case 290:
YY_RULE_SETUP
#line 777 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(0, 0, 0, 0, yyextra->AMD_gpu_shader_half_float_enable, &glsl_type_builtin_f16mat2);
	YY_BREAK
case 291:
YY_RULE_SETUP
#line 778 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(0, 0, 0, 0, yyextra->AMD_gpu_shader_half_float_enable, &glsl_type_builtin_f16mat2x3);
	YY_BREAK
case 292:
YY_RULE_SETUP
#line 779 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(0, 0, 0, 0, yyextra->AMD_gpu_shader_half_float_enable, &glsl_type_builtin_f16mat2x4);
	YY_BREAK
case 293:
YY_RULE_SETUP
#line 780 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(0, 0, 0, 0, yyextra->AMD_gpu_shader_half_float_enable, &glsl_type_builtin_f16mat3x2);
	YY_BREAK
case 294:
YY_RULE_SETUP
#line 781 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(0, 0, 0, 0, yyextra->AMD_gpu_shader_half_float_enable, &glsl_type_builtin_f16mat3);
	YY_BREAK
case 295:
YY_RULE_SETUP
#line 782 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(0, 0, 0, 0, yyextra->AMD_gpu_shader_half_float_enable, &glsl_type_builtin_f16mat3x4);
	YY_BREAK
case 296:
YY_RULE_SETUP
#line 783 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(0, 0, 0, 0, yyextra->AMD_gpu_shader_half_float_enable, &glsl_type_builtin_f16mat4x2);
	YY_BREAK
case 297:
YY_RULE_SETUP
#line 784 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(0, 0, 0, 0, yyextra->AMD_gpu_shader_half_float_enable, &glsl_type_builtin_f16mat4x3);
	YY_BREAK
case 298:
YY_RULE_SETUP
#line 785 "../src/compiler/glsl/glsl_lexer.ll"
TYPE_WITH_ALT(0, 0, 0, 0, yyextra->AMD_gpu_shader_half_float_enable, &glsl_type_builtin_f16mat4);
	YY_BREAK
case 299:
YY_RULE_SETUP
#line 787 "../src/compiler/glsl/glsl_lexer.ll"
{
			    struct _mesa_glsl_parse_state *state = yyextra;
			    if (state->es_shader && yyleng > 1024) {
			       _mesa_glsl_error(yylloc, state,
			                        "Identifier `%s' exceeds 1024 characters",
			                        yytext);
			    }
			    return classify_identifier(state, yytext, yyleng, yylval);
			}
	YY_BREAK
case 300:
YY_RULE_SETUP
#line 797 "../src/compiler/glsl/glsl_lexer.ll"
{ struct _mesa_glsl_parse_state *state = yyextra;
			  state->is_field = true;
			  return DOT_TOK; }
	YY_BREAK
case 301:
YY_RULE_SETUP
#line 801 "../src/compiler/glsl/glsl_lexer.ll"
{ return yytext[0]; }
	YY_BREAK
case 302:
YY_RULE_SETUP
#line 803 "../src/compiler/glsl/glsl_lexer.ll"
YY_FATAL_ERROR( "flex scanner jammed" );
	YY_BREAK
#line 3724 "src/compiler/glsl/glsl_lexer.cpp"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(PP):
case YY_STATE_EOF(PRAGMA):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_last_accepting_cpos;
				yy_current_state = yyg->yy_last_accepting_state;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( yywrap( yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = yyg->yytext_ptr;
	int number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) (yyg->yy_c_buf_p - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			yyg->yy_c_buf_p = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  , yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size , yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yyg->yy_start;
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			yyg->yy_last_accepting_state = yy_current_state;
			yyg->yy_last_accepting_cpos = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 1187 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */
	char *yy_cp = yyg->yy_c_buf_p;

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		yyg->yy_last_accepting_state = yy_current_state;
		yyg->yy_last_accepting_cpos = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 1187 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 1186);

	(void)yyg;
	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			int offset = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr);
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin , yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( yyscanner ) )
						return 0;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file , yyscanner);
	yy_load_buffer_state( yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void yy_load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file , yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * @param yyscanner The scanner object.
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf , yyscanner );

	yyfree( (void *) b , yyscanner );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_flush_buffer( b , yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack(yyscanner);

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void yypop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER , yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (yyscan_t yyscanner)
{
	yy_size_t num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyrealloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b , yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr , yyscan_t yyscanner)
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) , yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n , yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n , yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE yyget_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int yyget_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int yyget_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
int yyget_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *yyget_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param _line_number line number
 * @param yyscanner The scanner object.
 */
void yyset_lineno (int  _line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_lineno called with no buffer" );
    
    yylineno = _line_number;
}

/** Set the current column.
 * @param _column_no column number
 * @param yyscanner The scanner object.
 */
void yyset_column (int  _column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_column called with no buffer" );
    
    yycolumn = _column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = _in_str ;
}

void yyset_out (FILE *  _out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = _out_str ;
}

int yyget_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void yyset_debug (int  _bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = _bdebug ;
}

/* Accessor methods for yylval and yylloc */

YYSTYPE * yyget_lval  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylval;
}

void yyset_lval (YYSTYPE *  yylval_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylval = yylval_param;
}

YYLTYPE *yyget_lloc  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylloc;
}
    
void yyset_lloc (YYLTYPE *  yylloc_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylloc = yylloc_param;
}
    
/* User-visible API */

/* yylex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */
int yylex_init(yyscan_t* ptr_yy_globals)
{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* yylex_init_extra has the same functionality as yylex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to yyalloc in
 * the yyextra field.
 */
int yylex_init_extra( YY_EXTRA_TYPE yy_user_defined, yyscan_t* ptr_yy_globals )
{
    struct yyguts_t dummy_yyguts;

    yyset_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), &dummy_yyguts );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    yyset_extra (yy_user_defined, *ptr_yy_globals);

    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = NULL;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = NULL;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER , yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	yyfree(yyg->yy_buffer_stack , yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        yyfree( yyg->yy_start_stack , yyscanner );
        yyg->yy_start_stack = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    yyfree ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s , yyscan_t yyscanner)
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 803 "../src/compiler/glsl/glsl_lexer.ll"


int
classify_identifier(struct _mesa_glsl_parse_state *state, const char *name,
                    unsigned name_len, YYSTYPE *output)
{
   /* We're not doing linear_strdup here, to avoid an implicit call on
    * strlen() for the length of the string, as this is already found by flex
    * and stored in yyleng
    */
   char *id = (char *) linear_alloc_child(state->linalloc, name_len + 1);
   memcpy(id, name, name_len + 1);
   output->identifier = id;

   if (state->is_field) {
      state->is_field = false;
      return FIELD_SELECTION;
   }
   if (state->symbols->get_variable(name) || state->symbols->get_function(name))
      return IDENTIFIER;
   else if (state->symbols->get_type(name))
      return TYPE_IDENTIFIER;
   else
      return NEW_IDENTIFIER;
}

void
_mesa_glsl_lexer_ctor(struct _mesa_glsl_parse_state *state, const char *string)
{
   yylex_init_extra(state, & state->scanner);
   yy_scan_string(string, state->scanner);
}

void
_mesa_glsl_lexer_dtor(struct _mesa_glsl_parse_state *state)
{
   yylex_destroy(state->scanner);
}

